/***************************************************

Creator:	Elior

Date:		March 2014

Description: This file creates TABLE A1 in the online appendix:
			 Wage by Education of All Working Members in One 
			 Particular Kibbutz Pre and Post Reform

*****************************************************/

clear all
set mem 200m
set matsize 800
set more off
set logtype text

global name Table_A1

local today="$S_DATE"
local day=word("`today'",1)
local month=word("`today'",2)
local year=substr(word("`today'",3),3,2)
if `day'<10 local day="0`day'" 

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
**************************************************/
cd "C:\Users\msvictor3\Dropbox\Work\Kibbutzim\Online Appendix"

use data\appendix_data, clear

*******Open log******* 
cap log close
log using "logs\\${name}_`day'`month'`year'.log", replace

matrix A1 = J(4,7,.)
matrix rownames A1 = HS COL MA PHD
matrix colnames A1 = N_ALL N_NOOUT PRE_WAGE POST_MEAN_WAGE_ALL POST_MEAN_WAGE_NOOUT POST_MEDIAN_WAGE_ALL POST_MEDIAN_WAGE_NOOUT

***** COLUMN 1 : NUMBER OF OBSERVATIONS ALL *****
count if  eductypegr == 0 & kibbutz == 1
matrix A1[1,1] = r(N)
count if  eductypegr == 1 & kibbutz == 1
matrix A1[2,1] = r(N)
count if  eductypegr == 2 & kibbutz == 1
matrix A1[3,1] = r(N)
count if  eductypegr == 3 & kibbutz == 1
matrix A1[4,1] = r(N)

***** COLUMN 2 : NUMBER OF OBSERVATIONS NO OUTLIERS (WAGE UNDER 2000) *****
count if  eductypegr == 0 & wage >= 2000 & kibbutz == 1
matrix A1[1,2] = r(N)
count if  eductypegr == 1 & wage >= 2000 & kibbutz == 1
matrix A1[2,2] = r(N)
count if  eductypegr == 2 & wage >= 2000 & kibbutz == 1
matrix A1[3,2] = r(N)
count if  eductypegr == 3 & wage >= 2000 & kibbutz == 1
matrix A1[4,2] = r(N)

***** COLUMN 3 : PRE REFORM MEAN/MEDIAN WAGE ALL *****
su wage if kibbutz == 1
matrix A1[1,3] = r(mean)
matrix A1[2,3] = r(mean)
matrix A1[3,3] = r(mean)
matrix A1[4,3] = r(mean)

***** COLUMN 4 + 6 : PRE REFORM MEAN/MEDIAN WAGE ALL *****
su wage if  eductypegr == 0 & kibbutz == 1, det
matrix A1[1,4] = r(mean)
matrix A1[1,6] = r(p50)
su wage if  eductypegr == 1 & kibbutz == 1, det 
matrix A1[2,4] = r(mean)
matrix A1[2,6] = r(p50)
su wage if  eductypegr == 2 & kibbutz == 1, det
matrix A1[3,4] = r(mean)
matrix A1[3,6] = r(p50)
su wage if  eductypegr == 3 & kibbutz == 1, det
matrix A1[4,4] = r(mean)
matrix A1[4,6] = r(p50)

***** COLUMN 5 + 7 : PRE REFORM MEAN/MEDIAN WAGE NO OUTLIERS (WAGE UNDER 2000) *****
su wage if  eductypegr == 0 & wage >= 2000 & kibbutz == 1, det
matrix A1[1,5] = r(mean)
matrix A1[1,7] = r(p50)
su wage if  eductypegr == 1 & wage >= 2000 & kibbutz == 1, det 
matrix A1[2,5] = r(mean)
matrix A1[2,7] = r(p50)
su wage if  eductypegr == 2 & wage >= 2000 & kibbutz == 1, det
matrix A1[3,5] = r(mean)
matrix A1[3,7] = r(p50)
su wage if  eductypegr == 3 & wage >= 2000 & kibbutz == 1, det
matrix A1[4,5] = r(mean)
matrix A1[4,7] = r(p50)

/*************************************************************
IV. Reformat from dta to csv
**************************************************************/
clear 

svmat A1, names( col )

outsheet using "results\automatic\\${name}_`day'`month'`year'.csv", replace comma

cap log close
