/***************************************************

Creator:	Elior

Date:		February 2014

Description: This file creates TABLE A11 in the paper:
			 Balancing Test of Characteristics of Students 
			 Who Faced Different Intensities of Reform

*****************************************************/

clear all
set mem 200m
set matsize 800
set more off
set logtype text

global name Table_A11

local today="$S_DATE"
local day=word("`today'",1)
local month=word("`today'",2)
local year=substr(word("`today'",3),3,2)
if `day'<10 local day="0`day'" 

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
**************************************************/
cd "C:\Users\\Dropbox\Work\Kibbutzim\Online Appendix"

use data\kibbutzim, clear

/*******************************************
II. Define samples
*******************************************/
local allobs "id !=."

/*******************************************
III. Define "before" and "after"
*******************************************/

local Cohs1 "(year==1995| year==1996| year==1999| year==2000)"
local Cohs2 "(year==1995| year==1996| year==1997| year==1998| year==1999| year==2000)"

/*******************************************
IV. Define REFORM INTENSITY VARIABLE
*******************************************/
gen tipul = year + 3 - year_of_reform if year_of_reform != 99999
replace tipul = 0 if tipul < 0 | tipul == .  
replace tipul = 3 if tipul > 3
replace tipul = tipul /3
replace tipul = 0 if year < 1997
replace tipul = tipul - 1/3 if tipul > 0 & (year == 1997 | year == 1998)
replace tipul = 0 if tipul > 0 & tipul < 0.1
replace tipul = 1 if year > year_of_reform & year > 1998 
replace tipul = 2/3 if year == year_of_reform  
replace tipul = 1/3 if year == year_of_reform - 1 & year > 1998
replace tipul = 0 if year == year_of_reform - 2 & year > 1998
tab tipul year

gen ref9802 = (ref9800 == 1 | year_of_reform == 2001 | year_of_reform == 2002)

gen tipulf = tipul
replace tipulf = 0 if meshulav == 1

xi I.year, prefix(_I)

rename ref9800 T1
rename ref9802 T2
rename ref0304 C1


/*******************************************
V. Run balancing regressions
*******************************************/
local backgrounds "boy educ_av educ_em m_ahim eth_aa eth_ea eth_imm eth_fsu"

local outcomes "tipulf tipul"

local se "cluster(kibbutz)"

local tgroups "T1 T2"

local cgroups "C1"

local samples "allobs"

local cohs "Cohs1 Cohs2"

*******Open log******* 
cap log close
log using "logs\\${name}_`day'`month'`year'.log", replace

postfile values str50 rowKey T1 T2 T3 T4 using "results\automatic\\${name}.dta", replace

foreach sample in `samples' {

	foreach treatment in `tgroups'  {

		foreach control in `cgroups' {	
		
			foreach cohort in `cohs'  {
			
				foreach outcome in `outcomes' {

				cap drop treatment
				cap drop control

				di "gen treatment=`treatment'"
				gen treatment=`treatment'
				di ""
				
				di "gen control=`control'"
				gen control=`control'
				di ""

				//Calculate observations in each group
				*Treatment
				di "count if treatment==1 & ``cohort'' & ``sample'' & kibbutz !=."
				count if treatment==1 & ``cohort'' & ``sample'' & kibbutz !=.
				di ""
				scalar obsT_`cohort'=r(N)

				*Control
				di "count if control==1 & ``cohort'' & ``sample'' & kibbutz !=."
				count if control==1 & ``cohort'' & ``sample'' & kibbutz !=.
				di ""
				scalar obsC_`cohort'=r(N)
				
				local obs_`cohort'_`outcome'_`treatment' = obsT_`cohort' + obsC_`cohort'
				
				tab tipul if ``cohort'' & (treatment==1| control==1) & ``sample''
				
				//Calculate within-cohort differences
				di ""
				di "**********************************************************************************"
				di ""
				di ""
				di "Cohort: `cohort'"
				di ""
				di "**********************************************************************************"
				di ""

				di "reg `outcome' `backgrounds' if ``cohort'' & (treatment==1| control==1) & ``sample'' , `se'"
				reg `outcome' `backgrounds' _I* if ``cohort'' & (treatment==1| control==1) & ``sample'' , `se'
				di ""
				
					foreach bground in `backgrounds' {
						local B_`bground'_`cohort'_`outcome'_`treatment'     = _b[`bground']
						local se_`bground'_`cohort'_`outcome'_`treatment'  = _se[`bground']
					}
					
				test `backgrounds' 
				local F_`cohort'_`outcome'_`treatment' = r(F)
				local P_`cohort'_`outcome'_`treatment' = r(p)
			}
			}
			
		}
	}
}

foreach bground in `backgrounds' {
					
	post values ("B_`bground'")	      (`B_`bground'_Cohs1_tipulf_T1') (`B_`bground'_Cohs1_tipul_T1') (`B_`bground'_Cohs2_tipul_T1') (`B_`bground'_Cohs2_tipul_T2') 
	post values ("SD/SE_`bground'")	  (`se_`bground'_Cohs1_tipulf_T1') (`se_`bground'_Cohs1_tipul_T1') (`se_`bground'_Cohs2_tipul_T1') (`se_`bground'_Cohs2_tipul_T2')  
	post values ("Gap_`bground'")     (.)   (.) (.) (.)                   		  
				
	}
	
post values ("F-STATISTIC")		    (`F_Cohs1_tipulf_T1') (`F_Cohs1_tipul_T1') (`F_Cohs2_tipul_T1') (`F_Cohs2_tipul_T2') 
post values ("Gap")   				(.) (.) (.) (.)  			    
post values ("P-VALUE")				(`P_Cohs1_tipulf_T1') (`P_Cohs1_tipul_T1') (`P_Cohs2_tipul_T1') (`P_Cohs2_tipul_T2') 
post values ("Gap")     			(.)    (.) (.) (.)  
post values ("Obs")					(`obs_Cohs1_tipulf_T1') (`obs_Cohs1_tipul_T1') (`obs_Cohs2_tipul_T1') (`obs_Cohs2_tipul_T2') 


postclose values
	
cap log close

/*************************************************************
III. Reformat from dta to csv
**************************************************************/

use "results\automatic\\${name}", clear

outsheet using "results\automatic\\${name}_`day'`month'`year'.csv", replace comma

erase "results\automatic\\${name}.dta"
