/***************************************************

Creator:    Elior

Created:	February 2014

Description: This file creates Table A13: Treatment-Control Differences
             in Pre-Reform Time Trends in Schooling Outcomes, 10th Grade
			 Students in 1993-1998 Treatment Kibbutzim : Reformed in 1998-2000; 
			 Control Kibbutzim : Did Not Reform

			
*****************************************************/

clear all
set mem 500m
set matsize 800
set more off
set logtype text

global name Table_A13 

local today="$S_DATE"
local day=word("`today'",1)
local month=word("`today'",2)
local year=substr(word("`today'",3),3,2)
if `day'<10 local day="0`day'" 

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
**************************************************/
cd "C:\Users\msvictor3\Dropbox\Work\Kibbutzim\Kibbutzim_ECMA"

use data\kibbutzim, clear

/**************************************************
II. CREATE TIME TREND VARIABLES
**************************************************/
//Time trend
gen time=year-1992 if year>=1993 & year<=1998
tab year
tab time

//Vars by kibbutz and year
egen zakaut=mean(zakai_intime), by (kibbutz year)
su zakaut

egen memutza=mean(wmean), by (kibbutz year)
su memutza

//Keep kibbutzim only
egen t=tag(kibbutz year)
drop if t==0
drop t
	
/*******************************************
III. Define sets
*******************************************/
local set_9398 "1993 1994 1995 1996 1997 1998"
local set_9498 "1994 1995 1996 1997 1998"

// DEFINE NO REFORM INDICATOR
gen noref =  (year_of_reform == 99999)

/*******************************************
VI. Run DID regresssions
*******************************************/
local tgroups "ref9800"
local cgroups "noref"

local sets "set_9398"
local sets2 "set_9498"

local vars "zakaut memutza"

foreach treatment in `tgroups'  {
	
	foreach control in `cgroups' {

		foreach set in `sets' {
		
			*******Open log******* 
			cap log close
			log using "logs\\${name}_`day'`month'`year'.log", replace
			**********************
			postfile values str50 rowKey B1 B2 B3 B4 using "results\automatic\\${name}", replace

				foreach var in `vars' {

					cap drop years
					cap drop treatment
					cap drop control
					cap drop timeXtreatment
					cap drop _Iyear*
					cap drop _TrXIyear*

					di "egen years = anymatch(year), values(``set'')"
					egen years = anymatch(year), values(``set'')

					di "gen treatment=`treatment'"
					gen treatment=`treatment'
					di ""

					di "gen control=`control'"
					gen control=`control'
					di ""

					di "gen timeXtreatment = time*treatment"
					gen timeXtreatment = time*treatment
					di ""

					//Create year dummies
					
						foreach yearRel in ``sets2'' {

							di "gen _Iyear`yearRel'=(year==`yearRel')"
							gen _Iyear`yearRel'=(year==`yearRel')

							di "gen _TrXIyear`yearRel'=_Iyear`yearRel'*treatment"
							gen _TrXIyear`yearRel'=_Iyear`yearRel'*treatment
						}		

					//Continuous regressions

					di ""
					di "************************************************************************"
					di ""
					di "Variable: `var'"
					di ""
					di "Simple DID, Continuous"
					di ""
					di "Set: `set'"
					di ""
					di "************************************************************************"

					di "reg `var' time treatment timeXtreatment if (treatment==1 | control==1) & years==1"
					reg `var' time treatment timeXtreatment if (treatment==1 | control==1) & years==1 
					di ""

					local b_Tr2_`var'  = _b[treatment]
					local se_Tr2_`var' = _se[treatment]

					local b1_time_`var'   = _b[time]
					local se1_time_`var'  = _se[time]

					local b1_trXtime_`var'   = _b[timeXtreatment]
					local se1_trXtime_`var'  = _se[timeXtreatment]

					di ""
					di "************************************************************************"
					di ""
					di "Variable: `var'"
					di ""
					di "DID + kibbutz FE, Continuous"
					di ""
					di "Set: `set'"
					di ""
					di "************************************************************************"

					di "areg `var' time timeXtreatment if (treatment==1 | control==1) & years==1, absorb(kibbutz)"
					areg `var' time timeXtreatment if (treatment==1 | control==1) & years==1, absorb(kibbutz) 
					di ""

					local b2_time_`var'   = _b[time]
					local se2_time_`var'  = _se[time]

					local b2_trXtime_`var'   = _b[timeXtreatment]
					local se2_trXtime_`var'  = _se[timeXtreatment]


					//Regressions with year dummies

					di ""
					di "************************************************************************"
					di ""
					di "Variable: `var'"
					di ""
					di "Simple DID, Year dummies"
					di ""
					di "Set: `set'"
					di ""
					di "************************************************************************"

					di "reg `var' _Iyear* treatment _TrXIyear* if (treatment==1 | control==1) & years==1"
					reg `var' _Iyear* treatment _TrXIyear* if (treatment==1 | control==1) & years==1 
					di ""

					local b_Tr1_`var'  = _b[treatment]
					local se_Tr1_`var' = _se[treatment]
					
					//F-test
					di "testparm _TrXIyear*"
					testparm _TrXIyear*
					di ""
					
					local F1_`var' = r(F)
					local P1_`var' = r(p)

						foreach yearRel in ``sets2'' {
					
							local b_t1_`yearRel'_`var'  = _b[_TrXIyear`yearRel']
							local se_t1_`yearRel'_`var' = _se[_TrXIyear`yearRel']
						
						}

					di ""
					di "************************************************************************"
					di ""
					di "Variable: `var'"
					di ""
					di "DID + kibbutz FE, Year dummies"
					di ""
					di "Set: `set'"
					di ""
					di "************************************************************************"

					di "areg `var' _Iyear* _TrXIyear* if (treatment==1 | control==1) & years==1, absorb(kibbutz)"
					areg `var' _Iyear* _TrXIyear* if (treatment==1 | control==1) & years==1, absorb(kibbutz) 
					di ""
				
						foreach yearRel in ``sets2'' {
				
							local b_t2_`yearRel'_`var'  = _b[_TrXIyear`yearRel']
							local se_t2_`yearRel'_`var' = _se[_TrXIyear`yearRel']
							
						
						}
				
					//F-test
					di "testparm _TrXIyear*"
					testparm _TrXIyear*
					di ""

					local F2_`var' = r(F)
					local P2_`var' = r(p)
	
					}
				
			//Post results

			post values ("time_B")      (`b1_time_zakaut')     (`b2_time_zakaut') 		(`b1_time_memutza')     (`b2_time_memutza')   
			post values ("time_SE")     (`se1_time_zakaut')    (`se2_time_zakaut')	  	(`se1_time_memutza')    (`se2_time_memutza')
			post values ("gap")         (.)             	   (.)    			  		(.)					  	(.)
			post values ("timeXTr_B")   (`b1_trXtime_zakaut')  (`b2_trXtime_zakaut')    (`b1_trXtime_memutza')  (`b2_trXtime_memutza') 
			post values ("timeXTr_SE")  (`se1_trXtime_zakaut') (`se2_trXtime_zakaut')   (`se1_trXtime_memutza') (`se2_trXtime_memutza')
			post values ("gap")         (.)             	   (.)						(.)						(.) 
			post values ("Tr_B")        (`b_Tr2_zakaut')       (.)						(`b_Tr2_memutza')       (.) 
			post values ("Tr_SE")       (`se_Tr2_zakaut')      (.)						(`se_Tr2_memutza')      (.)
			 
			post values ("gap")         (.)            		   (.)						(.)						(.)
			post values ("gap")         (.)                    (.)                      (.)  					(.)
			post values ("gap")         (.)                    (.)                      (.)						(.)
			
				foreach yearRel in ``sets2'' {
					post values ("Year_`yearRel'_B")   (`b_t1_`yearRel'_zakaut')	(`b_t2_`yearRel'_zakaut')	(`b_t1_`yearRel'_memutza')   (`b_t2_`yearRel'_memutza')  
					post values ("Year_`yearRel'_SE")  (`se_t1_`yearRel'_zakaut')   (`se_t2_`yearRel'_zakaut')	(`se_t1_`yearRel'_memutza')  (`se_t2_`yearRel'_memutza')
					post values ("gap")                (.)                  		(.)							(.)							 (.)         
				}
			
			post values ("Tr_B")       			(`b_Tr1_zakaut')	(.)				(`b_Tr1_memutza')	(.)
			post values ("Tr_SE")      			(`se_Tr1_zakaut')	(.)				(`se_Tr1_memutza')	(.)
			post values ("F_Statistic")       	(`F1_zakaut')	 	(`F2_zakaut')	(`F1_memutza')	 	(`F2_memutza')
			post values ("P_Value")      		(`P1_zakaut')	 	(`P2_zakaut')	(`P1_memutza')	 	(`P2_memutza')
		
			postclose values
			cap log close
		}
	}
}


/*************************************************************
III. Reformat all postfiles from dta to csv
**************************************************************/

foreach treatment in `tgroups'  {

	foreach control in `cgroups' {

		foreach set in `sets' {

			foreach var in `vars' {

				preserve

				use "results\automatic\\${name}", clear

				outsheet using "results\automatic\\${name}.csv", replace comma
				
				
				restore

			}
		}
	}
}
erase "results\automatic\\${name}.dta"
