/***************************************************

Creator:	Elior

Date:		February 2014

Description: This file creates TABLE A14 in the paper:
			Treatment-Control and Between-Cohort Differences
			in Students' Exit Rates From Their Kibbutzim
			Treatment Kibbutzim : Reformed in 1998-2000;
			Control Kibbutzim : Reformed in 2001-2002

*****************************************************/

clear all
set mem 200m
set matsize 800
set more off
set logtype text

global name Table_A15

local today="$S_DATE"
local day=word("`today'",1)
local month=word("`today'",2)
local year=substr(word("`today'",3),3,2)
if `day'<10 local day="0`day'" 

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
**************************************************/
cd "C:\Users\msvictor3\Dropbox\Work\Kibbutzim\Kibbutzim_ECMA"

use data\kibbutzim, clear

/*******************************************
II. Define samples
*******************************************/
local allobs "id !=."

/*******************************************
III. Define "before" and "after"
*******************************************/

local set_9596_9900_Before "1995 1996"
local set_9596_9900_After "1999 2000"

local Cohs9596 "(year==1995| year==1996)"
local Cohs9900 "(year==1999| year==2000)"

// DEFINE NO REFORM INDICATOR
gen ref0102 =  (year_of_reform == 2001 | year_of_reform == 2002)

/*******************************************
IV. Run balancing regressions
*******************************************/
rename left_kib leftkib
local trends "leftkib"

local se "cluster(kibbutz)"

local tgroups "ref9800"

local cgroups "ref0102"

local samples "allobs"

local cohs "Cohs9596 Cohs9900"

local sets "act9596_9900"

*******Open log******* 
cap log close
log using "logs\\${name}_`day'`month'`year'.log", replace

postfile values str50 rowKey T1 C1 Dif1 using "results\automatic\\${name}", replace

foreach sample in `samples' {

	foreach treatment in `tgroups'  {

		foreach control in `cgroups' {

			foreach trend of varlist `trends' {

				foreach cohort in `cohs'  {

					cap drop treatment
					cap drop control

					di "gen treatment=`treatment'"
					gen treatment=`treatment'
					di ""

					di "gen control=`control'"
					gen control=`control'
					di ""

					//Calculate within-cohort differences
					di ""
					di "**********************************************************************************"
					di ""
					di "Outcome: `trend'"
					di ""
					di "Cohort: `cohort'"
					di ""
					di "**********************************************************************************"
					di ""

					di "su `trend'  if treatment==1 & ``cohort'' & ``sample''"
					su `trend'  if treatment==1 & ``cohort'' & ``sample''
					di ""
					local meanT_`trend'_`cohort'=r(mean)
					local sdT_`trend'_`cohort'=r(sd)

					di "su `trend'  if control==1 & ``cohort'' & ``sample''"
					su `trend'  if control==1 & ``cohort'' & ``sample''
					di ""
					local meanC_`trend'_`cohort'=r(mean)
					local sdC_`trend'_`cohort'=r(sd)

					di "reg `trend' treatment if ``cohort'' & (treatment==1| control==1) & ``sample'', `se'"
					reg `trend' treatment if ``cohort'' & (treatment==1| control==1) & ``sample'', `se'
					di ""
					local difTC_`trend'_`cohort'     = _b[treatment]
					local se_difTC_`trend'_`cohort'  = _se[treatment]

					}
					
					cap drop after
					cap drop before 
					
					di "egen before = anymatch(year), values(1995 1996)"
					egen before = anymatch(year), values(1995 1996)

					di "egen after  = anymatch(year), values(1999 2000)"
					egen after  = anymatch(year), values(1999 20000)
					
					di ""
					di "**********************************************************************************"
					di ""
					di "Between-cohort diffs"
					di ""
					di "Outcome: `trend'"
					di ""
					di "Set: `set'"
					di ""
					di "**********************************************************************************"
					di ""

					di "reg `trend' after if treatment == 1 & (before==1 | after==1) & ``sample'', `se'"
					reg `trend' after if treatment == 1 & (before==1 | after==1) & ``sample'', `se'
					di ""
								
					local DBT_`trend'   = _b[after]
					local SEDBT_`trend' = _se[after]


					di "reg `trend' after if control == 1 & (before==1 | after==1) & ``sample'', `se'"
					reg `trend' after if control == 1 & (before==1 | after==1) & ``sample'', `se'
					di ""
						
					local DBC_`trend'   = _b[after]
					local SEDBC_`trend' = _se[after]
					
				}
									
		}
	}
}

post values ("M_leftkib")	    (`meanT_leftkib_Cohs9596') (`meanC_leftkib_Cohs9596')  (`difTC_leftkib_Cohs9596')      
post values ("SD/SE_leftkib")	(`sdT_leftkib_Cohs9596')   (`sdC_leftkib_Cohs9596')    (`se_difTC_leftkib_Cohs9596')    
post values ("Gap_leftkib")     (.)		                   (.)		                   (.)	                          	

post values ("M_leftkib")	    (`meanT_leftkib_Cohs9900') (`meanC_leftkib_Cohs9900')  (`difTC_leftkib_Cohs9900')      
post values ("SD/SE_leftkib")	(`sdT_leftkib_Cohs9900')   (`sdC_leftkib_Cohs9900')    (`se_difTC_leftkib_Cohs9900')    
post values ("Gap_leftkib")     (.)		                   (.)		                   (.)	      

post values ("D_leftkib")	  (`DBT_leftkib')     (`DBC_leftkib')    (.) 
post values ("SE_leftkib")    (`SEDBT_leftkib')	  (`SEDBC_leftkib')  (.) 
post values ("Gap_leftkib")   (.)		          (.)		         (.)	
	
postclose values

cap log close

/*************************************************************
III. Reformat from dta to csv
**************************************************************/

use "results\automatic\\${name}", clear

outsheet using "results\automatic\\${name}.csv", replace comma

erase "results\automatic\\${name}.dta"
