/***************************************************

Creator:    Elior

Created:	Febuary 2014

Description: This file creates Table A17:
	         Estimated Coefficients on Four Social Reforms Dummies
			
*****************************************************/

clear all
set mem 500m
set matsize 800
set more off
set logtype text

global name Table_A17 

local today="$S_DATE"
local day=word("`today'",1)
local month=word("`today'",2)
local year=substr(word("`today'",3),3,2)
if `day'<10 local day="0`day'" 

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
**************************************************/
cd "C:\Users\msvictor3\Dropbox\Work\Kibbutzim\Kibbutzim_ECMA"

use data\kibbutzim, clear

/*******************************************
II. Define `after' and `before'
*******************************************/
local act9596_9900Before "1995 1996"
local act9596_9900After "1999 2000"

local plac9596_9798Before "1995 1996"
local plac9596_9798After "1997 1998"

/*******************************************
III. Define samples
*******************************************/
//FULL SAMPLE
local allobs "id !=."

//By gender
gen girl = (boy == 0)

//By maternal education 
gen motH = (educ_em >= 14)

/*******************************************
IV. Run DID regresssions - PART I
*******************************************/
local depvars "graduate wmean zakai_bagrut university score"

local controls "boy educ_av educ_em m_ahim eth_*"

local reform_dummies "d_pay_meal d_pay_electricity d_pay_health d_pay_laundry" 

local cluster "cluster(kibbutz)"

local tgroups "ref9800"

local cgroups "ref0304"

local samples "allobs"

local sets "act9596_9900"

*******Open log******* 
cap log close
log using "logs\\${name}_`day'`month'`year'.log", replace
**********************

postfile values str50 rowKey graduate wmean zakai_bagrut university score using "results\automatic\\${name}", replace

foreach treatment in `tgroups'  {

	foreach control in `cgroups' {

		foreach sample in `samples' {

			foreach set in `sets' {

				//Define after and before periods
				cap drop after
				cap drop before
				cap drop treatment
				cap drop control
				cap drop afterXtreatment
				cap drop yearRelevant
				cap drop _Iyear*

				egen after  = anymatch(year), values(``set'After')
				egen before = anymatch(year), values(``set'Before')

				gen treatment=`treatment'
				gen control=`control'
				gen afterXtreatment = after*treatment

				//Create year dummies
				di ""
				di "gen yearRelevant = year if (before | after)"	
				gen yearRelevant = year if (before | after)

				di ""
				di "xi i.yearRelevant"
				xi i.yearRelevant

					foreach var of varlist `depvars' {

						//DID + year dummies + individual controls + kibbutz FE
						di ""
						di "**********************************************************************************"
						di ""
						di "DID + year dummies + individual controls + kibbutz FE"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'After', ``set'Before'"
						di ""
						di "Sample: `sample'"
						di ""
						di "**********************************************************************************"
						di ""
						* INCLUDING REFORM DUMMIES AS CONTROLS IN THE DID REGRESSION
						di "areg `var' afterXtreatment _Iyear* `controls' `reform_dummies' if (before | after) & (treatment==1| control==1) & ``sample'', absorb(kibbutz) `cluster'"
						areg `var' afterXtreatment _Iyear* `controls' `reform_dummies'  if (before | after) & (treatment==1| control==1) & ``sample'', absorb(kibbutz) `cluster'
						
						local B1_`var'  = _b[afterXtreatment]
						local SE1_`var' = _se[afterXtreatment]
						
						local B2_`var'  = _b[d_pay_meal]
						local SE2_`var' = _se[d_pay_meal]
						
						local B3_`var'  = _b[d_pay_electricity]
						local SE3_`var' = _se[d_pay_electricity]
						
						local B4_`var'  = _b[d_pay_health]
						local SE4_`var' = _se[d_pay_health]
						
						local B5_`var'  = _b[d_pay_laundry]
						local SE5_`var' = _se[d_pay_laundry]
						
					
						
				}		
				
			}
		}
	}
}

post values ("PAY REFORM")	     	(`B1_graduate')  (`B1_wmean')    (`B1_zakai_bagrut')    (`B1_university') (`B1_score')  
post values ("cluster SE")	         (`SE1_graduate') (`SE1_wmean')   (`SE1_zakai_bagrut')   (`SE1_university') (`SE1_score')
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)                              (.)                        		  


post values ("MEAL REFORM")	 		(`B2_graduate')  (`B2_wmean')    (`B2_zakai_bagrut')    (`B2_university') (`B2_score')   
post values ("cluster SE")	         (`SE2_graduate') (`SE2_wmean')   (`SE2_zakai_bagrut')   (`SE2_university') (`SE2_score') 
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)			                     (.)                                        	

post values ("ELECTRICITY REFORM")	 (`B3_graduate')  (`B3_wmean')    (`B3_zakai_bagrut')    (`B3_university') (`B3_score')   
post values ("cluster SE")	         (`SE3_graduate') (`SE3_wmean')   (`SE3_zakai_bagrut')   (`SE3_university') (`SE3_score') 
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)			                     (.)

post values ("HEALTH REFORM")	     (`B4_graduate')  (`B4_wmean')    (`B4_zakai_bagrut')    (`B4_university') (`B3_score')   
post values ("cluster SE")	         (`SE4_graduate') (`SE4_wmean')   (`SE4_zakai_bagrut')   (`SE4_university') (`SE3_score') 
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)	 (.)

post values ("LAUNDRY REFORM")	     (`B5_graduate')  (`B5_wmean')    (`B5_zakai_bagrut')    (`B5_university') (`B5_score')   
post values ("cluster SE")	         (`SE5_graduate') (`SE5_wmean')   (`SE5_zakai_bagrut')   (`SE5_university') (`SE5_score') 
post values ("")                     (.)		       			   (.)		     				(.)                   				(.) (.)	

postclose values 
/*************************************************************
V. Reformat from dta to csv
**************************************************************/

use "results\automatic\\${name}", clear

outsheet using "results\automatic\\${name}.csv", replace comma

erase "results\automatic\\${name}.dta"

cap log close
