/***************************************************

Creator:    Elior

Created:	Febuary 2014

Description: This file creates Table A17a:Cross-Section 
              Treatment-Control Differences and Difference 
			  in Differences Estimates (Including  Four  
			  Other Social Reforms as Controls)s
			
*****************************************************/

clear all
set mem 500m
set matsize 800
set more off
set logtype text

global name Table_A17a 

local today="$S_DATE"
local day=word("`today'",1)
local month=word("`today'",2)
local year=substr(word("`today'",3),3,2)
if `day'<10 local day="0`day'" 

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
**************************************************/
cd "C:\Users\msvictor3\Dropbox\Work\Kibbutzim\Kibbutzim_ECMA"

use data\kibbutzim, clear

/*******************************************
II. Define `after' and `before'
*******************************************/
local act9596_9900Before "1995 1996"
local act9596_9900After "1999 2000"

local plac9596_9798Before "1995 1996"
local plac9596_9798After "1997 1998"

/*******************************************
III. Define samples
*******************************************/
//FULL SAMPLE
local allobs "id !=."

/*******************************************
IV. Run DID regresssions - PART I
*******************************************/
local depvars "graduate wmean zakai_bagrut university score"

local controls "boy educ_av educ_em m_ahim eth_*"

local reform_dummies "d_pay_meal d_pay_electricity d_pay_health d_pay_laundry" 

local cluster "cluster(kibbutz)"

local tgroups "ref9800"

local cgroups "ref0304"

local samples "allobs"

local sets "act9596_9900 plac9596_9798"

*******Open log******* 
cap log close
log using "logs\\${name}_`day'`month'`year'.log", replace
**********************

postfile values str50 rowKey graduate wmean zakai_bagrut university score using "results\automatic\\${name}", replace

foreach treatment in `tgroups'  {

	foreach control in `cgroups' {

		foreach sample in `samples' {

			foreach set in `sets' {

				//Define after and before periods
				cap drop after
				cap drop before
				cap drop treatment
				cap drop control
				cap drop afterXtreatment
				cap drop yearRelevant
				cap drop _Iyear*

				egen after  = anymatch(year), values(``set'After')
				egen before = anymatch(year), values(``set'Before')

				gen treatment=`treatment'
				gen control=`control'
				gen afterXtreatment = after*treatment

				//Create year dummies
				di ""
				di "gen yearRelevant = year if (before | after)"	
				gen yearRelevant = year if (before | after)

				di ""
				di "xi i.yearRelevant"
				xi i.yearRelevant

					foreach var of varlist `depvars' {
					
						//Treatment-Control differences Before Treatment
						di ""
						di "**********************************************************************************"
						di ""
						di "Treatment-Control Diffs"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'Before'"
						di ""
						di "Sample: `sample'"
						di ""
						di "**********************************************************************************"
						di ""
						
						reg `var' treatment `controls' `reform_dummies' if before==1 & (treatment==1| control==1) & ``sample'', `cluster'
						di ""

						local B1_`var'_`set'  = _b[treatment]
						local SE1_`var'_`set' = _se[treatment]

						//Treatment-Control differences After Treatment
						di ""
						di "**********************************************************************************"
						di ""
						di "Treatment-Control Diffs"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'After'"
						di ""
						di "Sample: `sample'"
						di ""
						di "**********************************************************************************"
						di ""

						reg `var' treatment `controls' `reform_dummies' if after==1 & (treatment==1| control==1) & ``sample'', `cluster'
						di ""

						local B2_`var'_`set'  = _b[treatment]
						local SE2_`var'_`set' = _se[treatment]

						// Simple DID
						di ""
						di "**********************************************************************************"
						di ""
						di "Simple DID"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'After', ``set'Before'"
						di ""
						di "Sample: `sample'"
						di ""
						di "**********************************************************************************"
						di ""
						di "reg `var' after treatment afterXtreatment  _Iyear* if (before | after) & (treatment==1| control==1) & ``sample'', `cluster'"
						reg `var' after treatment afterXtreatment  _Iyear* if (before | after) & (treatment==1| control==1) & ``sample'', `cluster'
						
						local B3_`var'_`set'  = _b[afterXtreatment]
						local SE3_`var'_`set' = _se[afterXtreatment]

						//DID + year dummies + individual controls + kibbutz FE
						di ""
						di "**********************************************************************************"
						di ""
						di "DID + year dummies + individual controls + kibbutz FE"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'After', ``set'Before'"
						di ""
						di "Sample: `sample'"
						di ""
						di "**********************************************************************************"
						di ""
						* INCLUDING REFORM DUMMIES AS CONTROLS IN THE DID REGRESSION
						di "areg `var' afterXtreatment _Iyear* `controls' `reform_dummies' if (before | after) & (treatment==1| control==1) & ``sample'', absorb(kibbutz) `cluster'"
						areg `var' afterXtreatment _Iyear* `controls' `reform_dummies'  if (before | after) & (treatment==1| control==1) & ``sample'', absorb(kibbutz) `cluster'
						
						local B4_`var'_`set'  = _b[afterXtreatment]
						local SE4_`var'_`set' = _se[afterXtreatment]
						
				}		
				
			}
		}
	}
}

post values ("T-C Diffs Before")	 (`B1_graduate_act9596_9900')  (`B1_wmean_act9596_9900')  (`B1_zakai_bagrut_act9596_9900')   (`B1_university_act9596_9900') (`B1_score_act9596_9900') 
post values ("cluster SE1")	         (`SE1_graduate_act9596_9900') (`SE1_wmean_act9596_9900') (`SE1_zakai_bagrut_act9596_9900')  (`SE1_university_act9596_9900') (`SE1_score_act9596_9900')
post values ("")                     (.)		       			   (.)		     			  (.)                   		     (.)							(.)	  

post values ("T-C Diffs After")	     (`B2_graduate_act9596_9900')  (`B2_wmean_act9596_9900')  (`B2_zakai_bagrut_act9596_9900')   (`B2_university_act9596_9900')  (`B2_score_act9596_9900')  
post values ("cluster SE2")	         (`SE2_graduate_act9596_9900') (`SE2_wmean_act9596_9900') (`SE2_zakai_bagrut_act9596_9900')  (`SE2_university_act9596_9900')  (`SE2_score_act9596_9900')
post values ("")                     (.)		       			   (.)		     			  (.)                   		     (.)			  (.)


post values ("Simple DID act")	     (`B3_graduate_act9596_9900')  (`B3_wmean_act9596_9900')    (`B3_zakai_bagrut_act9596_9900')    (`B3_university_act9596_9900') (`B3_score_act9596_9900')   
post values ("cluster SE")	         (`SE3_graduate_act9596_9900') (`SE3_wmean_act9596_9900')   (`SE3_zakai_bagrut_act9596_9900')   (`SE3_university_act9596_9900') (`SE3_score_act9596_9900') 
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)                              (.)                        		  


post values ("Controlled DID act")	 (`B4_graduate_act9596_9900')  (`B4_wmean_act9596_9900')    (`B4_zakai_bagrut_act9596_9900')    (`B4_university_act9596_9900') (`B4_score_act9596_9900')   
post values ("cluster SE")	         (`SE4_graduate_act9596_9900') (`SE4_wmean_act9596_9900')   (`SE4_zakai_bagrut_act9596_9900')   (`SE4_university_act9596_9900') (`SE4_score_act9596_9900') 
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)			                     (.)                       

post values ("Simple DID plac")	     (`B3_graduate_plac9596_9798')  (`B3_wmean_plac9596_9798')    (`B3_zakai_bagrut_plac9596_9798')    (`B3_university_plac9596_9798') (`B3_score_plac9596_9798')   
post values ("cluster SE")	         (`SE3_graduate_plac9596_9798') (`SE3_wmean_plac9596_9798')   (`SE3_zakai_bagrut_plac9596_9798')   (`SE3_university_plac9596_9798') (`SE3_score_plac9596_9798') 
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)                              (.)                        		  


post values ("Controlled DID plac")	 (`B4_graduate_plac9596_9798')  (`B4_wmean_plac9596_9798')    (`B4_zakai_bagrut_plac9596_9798')    (`B4_university_plac9596_9798') (`B4_score_plac9596_9798')   
post values ("cluster SE")	         (`SE4_graduate_plac9596_9798') (`SE4_wmean_plac9596_9798')   (`SE4_zakai_bagrut_plac9596_9798')   (`SE4_university_plac9596_9798') (`SE4_score_plac9596_9798') 
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)			                     (.)                       

postclose values 
/*************************************************************
V. Reformat from dta to csv
**************************************************************/

use "results\automatic\\${name}", clear

outsheet using "results\automatic\\${name}.csv", replace comma

erase "results\automatic\\${name}.dta"

cap log close
