/***************************************************

Creator:    Elior

Created:	Febuary 2014

Description: This file creates Table A17b:Treatment-Control
	         Difference in Differences Estimates 
			(Treatment Measure = 0, 0.2 , 0.4 , 0.6, 0.8, 1) 
			DUMMY INDICATORS FOR TREATMENT INTENSITY
			
*****************************************************/

clear all
set mem 500m
set matsize 800
set more off
set logtype text

global name Table_A17b

local today="$S_DATE"
local day=word("`today'",1)
local month=word("`today'",2)
local year=substr(word("`today'",3),3,2)
if `day'<10 local day="0`day'" 

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
**************************************************/
cd "C:\Users\msvictor3\Dropbox\Work\Kibbutzim\Kibbutzim_ECMA"

use data\kibbutzim, clear

/*******************************************
II. Define `after' and `before'
*******************************************/
local act9596_9700Before "1995 1996"
local act9596_9700After "1997 1998 1999 2000"

/*******************************************
III. Define samples
*******************************************/
//FULL SAMPLE
local allobs "id !=."

/*******************************************
IV. Define TREATMENT INTENSITY
*******************************************/
gen tipul = year + 3 - year_of_reform if year_of_reform != 99999 & year_of_reform != . 
replace tipul = 0 if tipul < 0 | tipul == .  
replace tipul = 3 if tipul > 3
replace tipul = 0 if year < 1997
replace tipul = tipul - 1 if tipul > 0 & (year == 1997 | year == 1998)
replace tipul = 0 if tipul > 0 & tipul < 0.1
replace tipul = 3 if year > year_of_reform & year > 1998 
replace tipul = 2 if year == year_of_reform  
replace tipul = 1 if year == year_of_reform - 1 & year > 1998
replace tipul = 0 if year == year_of_reform - 2 & year > 1998
replace tipul = 0.5 if tipul == 0 & year_of_reform == year + 2
replace tipul = 4 if tipul == 3 & year_of_reform + 2 == year
replace tipul = 2 * tipul  
replace tipul = 3 if tipul == 4
replace tipul = 4 if tipul == 6
replace tipul = 5 if tipul == 8
replace tipul = tipul / 5
tab tipul year
xi I.tipul, prefix(_T)

/*******************************************
V. Run DID regresssions - PART I
*******************************************/
local depvars "graduate wmean zakai_bagrut university score"

local controls "boy educ_av educ_em m_ahim eth_*"

local cluster "cluster(kibbutz)"

local tgroups "ref9800"

local cgroups "ref0304"

local samples "allobs"

local sets "act9596_9700"

*******Open log******* 
cap log close
log using "logs\\${name}_`day'`month'`year'.log", replace
**********************

postfile values str50 rowKey graduate wmean zakai_bagrut university score using "results\automatic\\${name}", replace

foreach treatment in `tgroups'  {

	foreach control in `cgroups' {

		foreach sample in `samples' {

			foreach set in `sets' {

				//Define after and before periods
				cap drop after
				cap drop before
				cap drop treatment
				cap drop control
				cap drop afterXtreatment
				cap drop yearRelevant
				cap drop _Iyear*

				egen after  = anymatch(year), values(``set'After')
				egen before = anymatch(year), values(``set'Before')

				gen treatment=`treatment'
				gen control=`control'
				gen afterXtreatment = after*treatment

				//Create year dummies
				di ""
				di "gen yearRelevant = year if (before | after)"	
				gen yearRelevant = year if (before | after)

				di ""
				di "xi i.yearRelevant"
				xi i.yearRelevant

					foreach var of varlist `depvars' {
					
						//DID + year dummies + individual controls + kibbutz FE
						di ""
						di "**********************************************************************************"
						di ""
						di "DID + year dummies + individual controls + kibbutz FE"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'After', ``set'Before'"
						di ""
						di "Sample: `sample'"
						di ""
						di "**********************************************************************************"
						di ""
						di "areg `var' _T* _Iyear* `controls' if (before | after) & (treatment==1| control==1) & ``sample'', absorb(kibbutz) `se'"						
						areg `var' _T* _Iyear* `controls'  if (before | after) & (treatment==1| control==1) & ``sample'', absorb(kibbutz) `cluster'
						di ""
						
						local B1_`var'_`set'  = _b[_Ttipul_6]
						local B2_`var'_`set'  = _b[_Ttipul_5]
						local B3_`var'_`set'  = _b[_Ttipul_4]
						local B4_`var'_`set'  = _b[_Ttipul_3]
						local B5_`var'_`set'  = _b[_Ttipul_2]
						local SE1_`var'_`set' = _se[_Ttipul_6]
						local SE2_`var'_`set' = _se[_Ttipul_5]
						local SE3_`var'_`set' = _se[_Ttipul_4]
						local SE4_`var'_`set' = _se[_Ttipul_3]
						local SE5_`var'_`set' = _se[_Ttipul_2]
						
						
				}		
				
			}
		}
	}
}


post values ("3 YEARS MIDDLE SCHOOL") (`B1_graduate_act9596_9700')  (`B1_wmean_act9596_9700')    (`B1_zakai_bagrut_act9596_9700')    (`B1_university_act9596_9700')   (`B1_score_act9596_9700') 
post values ("cluster SE1")	         (`SE1_graduate_act9596_9700') (`SE1_wmean_act9596_9700')   (`SE1_zakai_bagrut_act9596_9700')   (`SE1_university_act9596_9700')   (`SE1_score_act9596_9700')
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)			                        (.)	
post values ("3 YEARS HIGH SCHOOL")	 (`B2_graduate_act9596_9700')  (`B2_wmean_act9596_9700')    (`B2_zakai_bagrut_act9596_9700')    (`B2_university_act9596_9700')    (`B2_score_act9596_9700') 
post values ("cluster SE2")	         (`SE2_graduate_act9596_9700') (`SE2_wmean_act9596_9700')   (`SE2_zakai_bagrut_act9596_9700')   (`SE2_university_act9596_9700')     (`SE2_score_act9596_9700')
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)			                         (.)	
post values ("2 YEAR")	 	 		 (`B3_graduate_act9596_9700')  (`B3_wmean_act9596_9700')    (`B3_zakai_bagrut_act9596_9700')    (`B3_university_act9596_9700')      (`B3_score_act9596_9700')  
post values ("cluster SE3")	         (`SE3_graduate_act9596_9700') (`SE3_wmean_act9596_9700')   (`SE3_zakai_bagrut_act9596_9700')   (`SE3_university_act9596_9700')      (`SE3_score_act9596_9700')
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)		                             (.)	
post values ("1 YEAR")	 	 		 (`B4_graduate_act9596_9700')  (`B4_wmean_act9596_9700')    (`B4_zakai_bagrut_act9596_9700')    (`B4_university_act9596_9700')       (`B4_score_act9596_9700') 
post values ("cluster SE4")	         (`SE4_graduate_act9596_9700') (`SE4_wmean_act9596_9700')   (`SE4_zakai_bagrut_act9596_9700')   (`SE4_university_act9596_9700')      (`SE4_score_act9596_9700')
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)                                   (.)
post values ("0 YEAR REFORM AFTER")	 (`B5_graduate_act9596_9700')  (`B5_wmean_act9596_9700')    (`B5_zakai_bagrut_act9596_9700')    (`B5_university_act9596_9700')        (`B5_score_act9596_9700') 
post values ("cluster SE5")	         (`SE5_graduate_act9596_9700') (`SE5_wmean_act9596_9700')   (`SE5_zakai_bagrut_act9596_9700')   (`SE5_university_act9596_9700')       (`SE5_score_act9596_9700')
post values ("")                     (.)		       			   (.)		     				(.)                   				(.)			 (.)		  
	                   
postclose values 
/*************************************************************
V. Reformat from dta to csv
**************************************************************/

use "results\automatic\\${name}", clear

outsheet using "results\automatic\\${name}.csv", replace comma

erase "results\automatic\\${name}.dta"

cap log close
