/***************************************************

Creator:    Elior

Created:	Febuary 2014

Description: This file creates Table A18: Controlled Difference
             in Differences Estimates by Level of Intensity
			 of Exposure to Full Differential Pay
			
*****************************************************/

clear all
set mem 500m
set matsize 800
set more off
set logtype text

global name Table_A18 

local today="$S_DATE"
local day=word("`today'",1)
local month=word("`today'",2)
local year=substr(word("`today'",3),3,2)
if `day'<10 local day="0`day'" 

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
**************************************************/
cd "C:\Users\msvictor3\Dropbox\Work\Kibbutzim\Kibbutzim_ECMA"

use data\kibbutzim, clear

/*******************************************
II. Define `after' and `before'
*******************************************/
local actual9596_9700Before "1995 1996"
local actual9596_9700After "1997 1998 1999 2000"

/*******************************************
III. Define samples
*******************************************/
//FULL SAMPLE
local allobs "id !=."

//CREATE INDICATOR FOR REFORM IN 1998-2002
gen ref9802 = (ref9800 == 1 | year_of_reform == 2001 | year_of_reform == 2002)

/*******************************************
IV. Create Treatment Intensity Indicators
*******************************************/
gen full = 0
replace full = year + 3 - ref_reshet if ref_reshet != 0 & (year == 1997 | year == 1998 | year == 1999| year == 2000)
replace full = 3 if full > 3
replace full = . if year_of_reform == .
replace full = 0 if full < 0 
tab full, m
gen full2 = full+1
tab full2, m
xi i.full, prefix (_Y) noomit 
gen _Yfull_1_2 = (_Yfull_1 == 1| _Yfull_2 == 1)

/*******************************************
IV. Run DID regresssions - PART I
*******************************************/
local depvars "graduate wmean zakai_bagrut university score"

local controls "boy educ_av educ_em m_ahim eth_*"

local reform_dummies "d_pay_meal d_pay_electricity d_pay_health d_pay_laundry" 

local cluster "cluster(kibbutz)"

local tgroups "ref9802"

local cgroups "ref0304"

local samples "allobs"

local sets "actual9596_9700"

*******Open log******* 
cap log close
log using "logs\\${name}_`day'`month'`year'.log", replace
**********************

postfile values str50 rowKey graduate wmean zakai_bagrut university score using "results\automatic\\${name}", replace

foreach treatment in `tgroups'  {

	foreach control in `cgroups' {

		foreach sample in `samples' {

			foreach set in `sets' {

				//Define after and before periods
				cap drop after
				cap drop before
				cap drop treatment
				cap drop control
				cap drop afterXtreatment
				cap drop yearRelevant
				cap drop _Iyear*

				egen after  = anymatch(year), values(``set'After')
				egen before = anymatch(year), values(``set'Before')

				gen treatment=`treatment'
				gen control=`control'
				gen afterXtr = after*treatment
				
				//Create interactions with reshet years dummies
				foreach Dum in  afterXtr {

							di "gen `Dum'Xfull_0 = `Dum'*_Yfull_0"
							gen `Dum'Xfull_0 = `Dum'*_Yfull_0

							di "gen `Dum'Xfull_1 = `Dum'*_Yfull_1"
							gen `Dum'Xfull_1 = `Dum'*_Yfull_1

							di "gen `Dum'Xfull_2 = `Dum'*_Yfull_2"
							gen `Dum'Xfull_2 = `Dum'*_Yfull_2

							di "gen `Dum'Xfull_1_2 = `Dum'*_Yfull_1_2"
							gen `Dum'Xfull_1_2 = `Dum'*_Yfull_1_2

							di "gen `Dum'Xfull_3 = `Dum'*_Yfull_3"
							gen `Dum'Xfull_3 = `Dum'*_Yfull_3

							di "gen `Dum'Xfull2 = `Dum'*full2"
							gen `Dum'Xfull2 = `Dum'*full2

						}

				//Create year dummies
				di ""
				di "gen yearRelevant = year if (before | after)"	
				gen yearRelevant = year if (before | after)

				di ""
				di "xi i.yearRelevant"
				xi i.yearRelevant
				
					//Count the number of students for each exposure group
					di ""
					di "su boy  if afterXtrXfull_0==1 & after==1 & treatment==1 & ``sample'' "
					su boy  if afterXtrXfull_0==1 & after==1 & treatment==1 & ``sample''
					local N0=r(N)

					di ""
					di "su boy  if afterXtrXfull_1==1 & after==1 & treatment==1 & ``sample''"
					su boy  if afterXtrXfull_1==1 & after==1 & treatment==1 & ``sample''
					local N1=r(N)

					di ""
					di "su boy  if afterXtrXfull_2==1 & after==1 & treatment==1 & ``sample''"
					su boy  if afterXtrXfull_2==1 & after==1 & treatment==1 & ``sample''
					local N2=r(N)

					di ""
					di "su boy  if afterXtrXfull_1_2==1 & after==1 & treatment==1 & ``sample''"
					su boy  if afterXtrXfull_1_2==1 & after==1 & treatment==1 & ``sample''
					local N12=r(N)


					di ""
					di "su boy if afterXtrXfull_3==1 & after==1 & treatment==1 & ``sample''"
					su boy  if afterXtrXfull_3==1 & after==1 & treatment==1 & ``sample''
					local N3=r(N)

					foreach var of varlist `depvars' {

						//TREATMENT INTENSITY DUMMIES + year dummies + individual controls + Kibbutz FE
						di ""
						di "**********************************************************************************"
						di "TREATMENT INTENSITY DUMMIES"
						di "DID grouped + year dummies + individual controls + Kibbutz FE"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'After', ``set'Before'"
						di ""
						di "Sample: `sample'"
						di ""
						di "**********************************************************************************"
						di ""
						
						di "areg `var' afterXtrXfull_0 afterXtrXfull_1 afterXtrXfull_2 afterXtrXfull_3 _Iyear*  `controls' `reform_dummies' if (before==1 | after==1) & (treatment==1 | control==1) & ``sample'', absorb(kibbutz) `cluster'"
						areg `var' afterXtrXfull_0 afterXtrXfull_1 afterXtrXfull_2 afterXtrXfull_3 _Iyear*  `controls' `reform_dummies'  if (before==1 | after==1) & (treatment==1 | control==1) & ``sample'',absorb(kibbutz)`cluster'
						
						local B4_`var'  = _b[afterXtrXfull_0]
						local SE4_`var' = _se[afterXtrXfull_0]

						local B5_`var'  = _b[afterXtrXfull_1]
						local SE5_`var' = _se[afterXtrXfull_1]

						local B6_`var'  = _b[afterXtrXfull_2]
						local SE6_`var' = _se[afterXtrXfull_2]

						local B7_`var'  = _b[afterXtrXfull_3]
						local SE7_`var' = _se[afterXtrXfull_3]
						
						test afterXtrXfull_0 = afterXtrXfull_1 = afterXtrXfull_2 = afterXtrXfull_3 = 0 
					
						local F3_`var' = r(F)
						local P3_`var' = r(p)
						
						//FULL VS. PARTIAL INTENSITY + year dummies + individual controls + Kibbutz FE
						di ""
						di "**********************************************************************************"
						di "FULL VS. PARTIAL INTENSITY"
						di "DID grouped + year dummies + individual controls + Kibbutz FE"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'After', ``set'Before'"
						di ""
						di "Sample: `sample'"
						di ""
						di "**********************************************************************************"
						di ""
						
						di "areg `var' afterXtrXfull_0 afterXtrXfull_3 _Iyear*  `controls' `reform_dummies' if afterXtrXfull_1_2==0 & (before==1 | after==1) & (treatment==1 | control==1) & ``sample'', absorb(kibbutz) `cluster'"
						areg `var' afterXtrXfull_0 afterXtrXfull_3 _Iyear*  `controls' `reform_dummies'  if afterXtrXfull_1_2==0 & (before==1 | after==1) & (treatment==1 | control==1) & ``sample'',absorb(kibbutz)`cluster'
						di ""
					 
						local GB1_`var'  = _b[afterXtrXfull_0]
						local GSE1_`var' = _se[afterXtrXfull_0]

						local GB2_`var'  = _b[afterXtrXfull_3]
						local GSE2_`var' = _se[afterXtrXfull_3]
						
					
						test afterXtrXfull_0 = afterXtrXfull_3 = 0 
						local F4_`var' = r(F)
						local P4_`var' = r(p)


				}		
				
			}
		}
	}
}


post values ("3 years_B_`N3'")	      (`B7_graduate')  (`B7_wmean')    (`B7_zakai_bagrut')    (`B7_university')  (`B7_score')  
post values ("3 years_SEC")	          (`SE7_graduate') (`SE7_wmean')   (`SE7_zakai_bagrut')   (`SE7_university') (`SE7_score')
post values ("3 years_Gap")                      (.)              (.)             (.)                    (.)                (.)   			  

post values ("2 years_B_`N2'")	 	  (`B6_graduate')  (`B6_wmean')    (`B6_zakai_bagrut')    (`B6_university') (`B6_score')  
post values ("2 years_SEC")	          (`SE6_graduate') (`SE6_wmean')   (`SE6_zakai_bagrut')   (`SE6_university') (`SE6_score')
post values ("2 years_Gap")                     (.)		       			   (.)		     				(.)                   				(.)			                     (.)                       	

post values ("1 years_B_`N1'")	      (`B5_graduate')  (`B5_wmean')    (`B5_zakai_bagrut')    (`B5_university') (`B5_score') 
post values ("1 years_SEC")           (`SE5_graduate') (`SE5_wmean')   (`SE5_zakai_bagrut')   (`SE5_university') (`SE5_score')
post values ("1 years_Gap")                   (.) (.) (.) (.) (.)  			  

post values ("0 years_B_`N0'")	      (`B4_graduate')  (`B4_wmean')    (`B4_zakai_bagrut')    (`B4_university') (`B4_score') 
post values ("0 years_SEC")	          (`SE4_graduate') (`SE4_wmean')   (`SE4_zakai_bagrut')   (`SE4_university') (`SE4_score')
post values ("0 years_Gap")                     (.)		       			   (.)		     				(.)                   				(.) (.)  			  

post values ("F first")	 		       (`F3_graduate')    (`F3_wmean')    (`F3_zakai_bagrut')     (`F3_university')	 (`F3_score') 
post values ("P first")	 		       (`P3_graduate')    (`P3_wmean')    (`P3_zakai_bagrut')     (`P3_university')	 (`P3_score')	

post values ("")                     (.)		       			   (.)		     				(.)                   				(.) (.)   			  
post values ("")                     (.)		       			   (.)		     				(.)                   				(.) (.)   			  

post values ("3 years_B_`N3'")	      (`GB2_graduate')  (`GB2_wmean')    (`GB2_zakai_bagrut')    (`GB2_university') (`GB2_score')  
post values ("3 years_SEC")	          (`GSE2_graduate') (`GSE2_wmean')   (`GSE2_zakai_bagrut')   (`GSE2_university') (`GSE2_score')
post values ("3 years_Gap")          (.)		       			   (.)		     				(.)                   				(.)                              (.)                        		  

post values ("0 years_B_`N0'")	       (`GB1_graduate')  (`GB1_wmean')    (`GB1_zakai_bagrut')    (`GB1_university') (`GB1_score')  
post values ("0 years_SEC")	          (`GSE1_graduate') (`GSE1_wmean')   (`GSE1_zakai_bagrut')   (`GSE1_university') (`GSE1_score')
post values ("0 years_Gap")          (.)		       (.)		        (.)                   	(.) (.)  			  

post values ("F second")	 		   (`F4_graduate')    (`F4_wmean')    (`F4_zakai_bagrut')     (`F4_university')	 (`F4_score') 
post values ("P second")	 		   (`P4_graduate')    (`P4_wmean')    (`P4_zakai_bagrut')     (`P4_university')	 (`P4_score')	
			       	

postclose values 
/*************************************************************
V. Reformat from dta to csv
**************************************************************/

use "results\automatic\\${name}", clear

outsheet using "results\automatic\\${name}.csv", replace comma

erase "results\automatic\\${name}.dta"

cap log close
