/***************************************************

Creator:    Elior

Created:	Febuary 2014

Description: This file creates Table A20: Controlled Difference-in
-Differences Estimates by Intensity of Exposure to Differential Pay,
 Sub-Samples by Gender
			
*****************************************************/

clear all
set mem 500m
set matsize 800
set more off
set logtype text

global name Table_A20

local today="$S_DATE"
local day=word("`today'",1)
local month=word("`today'",2)
local year=substr(word("`today'",3),3,2)
if `day'<10 local day="0`day'" 

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
**************************************************/
cd "C:\Users\msvictor3\Dropbox\Work\Kibbutzim\Kibbutzim_ECMA"

use data\kibbutzim, clear

/*******************************************
II. Define `after' and `before'
*******************************************/
local act9596_9900Before "1995 1996"
local act9596_9900After "1999 2000"

/*******************************************
III. Create Treatment Intensity Indicators
*******************************************/
gen full=0
replace full=year+3-ref_reshet if ref_reshet !=0 & (year==1999| year==2000)
replace full=3 if full>3
replace full=. if year_of_reform==.
tab full, m
gen full2=full+1
tab full2, m
xi i.full, prefix (_Y) noomit 
gen _Yfull_1_2=(_Yfull_1==1| _Yfull_2==1)

/*******************************************
IV. Define samples
*******************************************/
//FULL SAMPLE
local allobs "id !=."

//By gender
gen girl = (boy == 0)

//By maternal education 
gen motH = (educ_em >= 14)

//By paternal education 
gen fatH = (educ_av >= 13)

/*******************************************
V. Run DID regresssions - PART I
*******************************************/
local depvars "graduate wmean zakai_bagrut university score"

local controls "boy educ_av educ_em m_ahim eth_*"

local cluster "cluster(kibbutz)"

local tgroups "ref9800"

local cgroups "ref0304"

local samples "girl"

local sets "act9596_9900"

*******Open log******* 
cap log close
log using "logs\\${name}.log", replace
**********************

postfile values str50 rowKey graduate wmean zakai_bagrut university score using "results\automatic\\${name}", replace

foreach treatment in `tgroups'  {

	foreach control in `cgroups' {

		foreach set in `sets' {
		
			//Define after and before periods
			cap drop after
			cap drop before
			cap drop treatment
			cap drop control
			cap drop afterXtreatment
			cap drop yearRelevant
			cap drop _Yyear*

			egen after  = anymatch(year), values(``set'After')
			egen before = anymatch(year), values(``set'Before')

			gen treatment=`treatment'
			gen control=`control'
			gen afterXtreatment = after*treatment
			
			//Create interactions with reshet years dummies
			foreach Dum in  afterXtreatment {
			
				di "gen `Dum'Xfull_0 = `Dum'*_Yfull_0"
				gen `Dum'Xfull_0 = `Dum'*_Yfull_0

				di "gen `Dum'Xfull_1 = `Dum'*_Yfull_1"
				gen `Dum'Xfull_1 = `Dum'*_Yfull_1

				di "gen `Dum'Xfull_2 = `Dum'*_Yfull_2"
				gen `Dum'Xfull_2 = `Dum'*_Yfull_2

				di "gen `Dum'Xfull_1_2 = `Dum'*_Yfull_1_2"
				gen `Dum'Xfull_1_2 = `Dum'*_Yfull_1_2

				di "gen `Dum'Xfull_3 = `Dum'*_Yfull_3"
				gen `Dum'Xfull_3 = `Dum'*_Yfull_3

				di "gen `Dum'Xfull2 = `Dum'*full2"
				gen `Dum'Xfull2 = `Dum'*full2

			}

			//Create year dummies
			di ""
			di "gen yearRelevant = year if (before | after)"		
			gen yearRelevant = year if (before | after)

			di ""
			di "xi i.yearRelevant"
			xi i.yearRelevant , prefix(_Y)

			//Create kibbutz dummies
			cap drop Rel
			gen Rel = kibbutz if (before==1 | after==1) & (treatment==1 | control==1)
			xi i.Rel, prefix(_Kib)

			foreach sample in `samples' {
			
			
				//Create interactions with reshet years dummies
				foreach Dum in afterXtreatmentXfull_0 afterXtreatmentXfull_1 afterXtreatmentXfull_2 afterXtreatmentXfull_1_2 afterXtreatmentXfull_3 afterXtreatmentXfull2 {
			
					di "gen `Dum'X`sample' = `Dum'*`sample'"
					gen `Dum'X`sample' = `Dum'*`sample'

				}
			
					foreach x in boy educ_av educ_em m_ahim  eth_aa eth_ea eth_imm eth_fsu eth_eth  {
						
						gen `x'X`sample' = `x' * `sample' 
					}
				
				local controlsX`sample' "boyX`sample' educ_avX`sample' educ_emX`sample' m_ahimX`sample' eth_aaX`sample' eth_eaX`sample' eth_immX`sample' eth_fsuX`sample' eth_ethX`sample'"
				
					foreach year in _YyearRelev_1996 _YyearRelev_1999 _YyearRelev_2000 {
						
						gen `year'X`sample' = `year' * `sample'
						
					}
	
				foreach var of varlist `depvars' {
					
					di "su `var' if (before | after) & (treatment==1| control==1) & ``sample'' == 1 & Rel !=."
					su `var' if afterXtreatmentXfull_1_2 == 0 & (before | after) & (treatment==1| control==1) & `sample' == 1 & kibbutz !=.
					di ""
					local mean_`var'= r(mean)
					
					di "su `var' if (before | after) & (treatment==1| control==1) & ``sample'' == 0 & Rel !=."
					su `var' if afterXtreatmentXfull_1_2 == 0 & (before | after) & (treatment==1| control==1) & `sample' == 0 & kibbutz !=.
					di ""
					local mean_`var'_`sample'= r(mean) 

					
					//DID + year dummies + individual controls + kibbutz FE
					di ""
					di "**********************************************************************************"
					di ""
					di "DID + year dummies + individual controls + kibbutz FE"
					di ""
					di "Outcome: `var'"
					di ""
					di "Cohorts: ``set'After', ``set'Before'"
					di ""
					di "Sample: `sample' == 1 OR 0"
					di ""
					di "**********************************************************************************"
					
					di ""
					di "xi: reg `var' afterXtreatmentXfull_0 afterXtreatmentXfull_0X`sample' afterXtreatmentXfull_3 afterXtreatmentXfull_3X`sample' `sample' `controls' `controlsX`sample'' _Yyear* i.kibbutz*I.`sample' if (before | after) & (treatment==1| control==1), `cluster'"
					xi: reg `var' afterXtreatmentXfull_0 afterXtreatmentXfull_0X`sample' afterXtreatmentXfull_3 afterXtreatmentXfull_3X`sample' `sample' `controls' `controlsX`sample'' _Yyear* i.kibbutz*I.`sample' if afterXtreatmentXfull_1_2==0 & (before | after) & (treatment==1| control==1), `cluster'
					di ""
					
					local B1_`var'  = _b[afterXtreatmentXfull_3]
					local SE1_3_`var' = _se[afterXtreatmentXfull_3]
					
					local B2_`var'  = _b[afterXtreatmentXfull_0]
					local SE1_0_`var' = _se[afterXtreatmentXfull_0]
					
					local B1_`var'_`sample'  = _b[afterXtreatmentXfull_3] + _b[afterXtreatmentXfull_3X`sample']
					local B2_`var'_`sample'  = _b[afterXtreatmentXfull_0] + _b[afterXtreatmentXfull_0X`sample']
					
					matrix V = e(V)
					
					local SE1_3_`var'_`sample' = sqrt(V[3,3] + V[4,4] + 2 * V[4,3]) 
					local SE1_0_`var'_`sample' = sqrt(V[1,1] + V[2,2] + 2 * V[2,1]) 
					
					* WITHIN SAMPLES
					
					test afterXtreatmentXfull_0 = afterXtreatmentXfull_3 
					
					local F1_`var'_`sample' = r(F)
					local P1_`var'_`sample' = r(p)
					
					test afterXtreatmentXfull_0 + afterXtreatmentXfull_0X`sample' = afterXtreatmentXfull_3 + afterXtreatmentXfull_3X`sample'
					
					local F2_`var'_`sample' = r(F)
					local P2_`var'_`sample' = r(p)
					
					* BETWEEN SAMPLES
					
					test afterXtreatmentXfull_3X`sample' = 0
					
					local F3_`var'_`sample' = r(F)
					local P3_`var'_`sample' = r(p)
					
					test afterXtreatmentXfull_0X`sample' = 0
					
					local F4_`var'_`sample' = r(F)
					local P4_`var'_`sample' = r(p)
		
				}

			post values ("Cont. DID `sample' 1 3")	 (`B1_graduate')   (`B1_wmean')   (`B1_zakai_bagrut')    (`B1_university')  (`B1_score') 
			post values ("cluster SE")	             (`SE1_3_graduate')  (`SE1_3_wmean')  (`SE1_3_zakai_bagrut')   (`SE1_3_university') (`SE1_3_score')
			post values ("")                     	 (.)		       (.)		      (.)                    (.) (.)
			
			post values ("Cont. DID `sample' 1 0")	 (`B2_graduate')   (`B2_wmean')   (`B2_zakai_bagrut')    (`B2_university') (`B2_score') 
			post values ("cluster SE")	             (`SE1_0_graduate')  (`SE1_0_wmean')  (`SE1_0_zakai_bagrut')   (`SE1_0_university') (`SE1_0_score')
			post values ("")                     	 (.)		       (.)		      (.)                    (.) (.)
			
			post values ("")	                 	 (`mean_graduate') (`mean_wmean') (`mean_zakai_bagrut')  (`mean_university') (`mean_score') 
			post values ("F1 `sample'")	 		     (`F1_graduate_`sample'')    (`F1_wmean_`sample'')    (`F1_zakai_bagrut_`sample'')     (`F1_university_`sample'')  (`F1_score_`sample'') 
			post values ("P1 `sample'")	 		     (`P1_graduate_`sample'')    (`P1_wmean_`sample'')    (`P1_zakai_bagrut_`sample'')     (`P1_university_`sample'')  (`P1_score_`sample'')
			post values ("")                         (.)		       (.)		      (.)                    (.)  (.)
			
			post values ("Cont. DID `sample' 0 3")	 (`B1_graduate_`sample'')   (`B1_wmean_`sample'')   (`B1_zakai_bagrut_`sample'')    (`B1_university_`sample'')   (`B1_score_`sample'')  
			post values ("Cluster SE")	             (`SE1_3_graduate_`sample'')  (`SE1_3_wmean_`sample'')  (`SE1_3_zakai_bagrut_`sample'')   (`SE1_3_university_`sample'') (`SE1_3_score_`sample'')
			post values ("")                         (.)		       (.)		      (.)                    (.)       (.)
			
			post values ("Cont. DID `sample' 0 0")	 (`B2_graduate_`sample'')   (`B2_wmean_`sample'')   (`B2_zakai_bagrut_`sample'')    (`B2_university_`sample'')    (`B2_score_`sample'') 
			post values ("")	                     (`SE1_0_graduate_`sample'')  (`SE1_0_wmean_`sample'')  (`SE1_0_zakai_bagrut_`sample'')   (`SE1_0_university_`sample'')  (`SE1_0_score_`sample'')
			post values ("")                         (.)		       (.)		      (.)                    (.)         (.)
 			
			post values ("")	                     (`mean_graduate_`sample'') (`mean_wmean_`sample'') (`mean_zakai_bagrut_`sample'')  (`mean_university_`sample'')  (`mean_score_`sample'') 
			post values ("F2 `sample'")	 		     (`F2_graduate_`sample'')    (`F2_wmean_`sample'')    (`F2_zakai_bagrut_`sample'')     (`F2_university_`sample'')  (`F2_score_`sample'') 
			post values ("P2 `sample'")	 		     (`P2_graduate_`sample'')    (`P2_wmean_`sample'')    (`P2_zakai_bagrut_`sample'')     (`P2_university_`sample'')  (`P2_score_`sample'')
			
			post values ("")                         (.)		       (.)		      (.)                    (.)  (.)
			post values ("F3 `sample'")	 		     (`F3_graduate_`sample'')    (`F3_wmean_`sample'')    (`F3_zakai_bagrut_`sample'')     (`F3_university_`sample'')  (`F3_score_`sample'') 
			post values ("P3 `sample'")	 		     (`P3_graduate_`sample'')    (`P3_wmean_`sample'')    (`P3_zakai_bagrut_`sample'')     (`P3_university_`sample'')   (`P3_score_`sample'')
			post values ("F4 `sample'")	 		     (`F4_graduate_`sample'')    (`F4_wmean_`sample'')    (`F4_zakai_bagrut_`sample'')     (`F4_university_`sample'')   (`F4_score_`sample'') 
			post values ("P4 `sample'")	 		     (`P4_graduate_`sample'')    (`P4_wmean_`sample'')    (`P4_zakai_bagrut_`sample'')     (`P4_university_`sample'')   (`P4_score_`sample'')
			
			}

		}
	
	}
}

postclose values 
/*************************************************************
V. Reformat from dta to csv
**************************************************************/

use "results\automatic\\${name}", clear

outsheet using "results\automatic\\${name}.csv", replace comma

erase "results\automatic\\${name}.dta"

cap log close
