/************************************************

Creator: Elior

Created: Febuary 2014

Description: This file creates Table A21: Post Secondary
              Enrollment and Years of Schooling in Treatment
			  and Control Kibbutzim
			 
*************************************************/

clear all
set mem 500m
set matsize 800
set more off
set logtype text

global name Table_A21

local today = "$S_DATE"
local day = word("`today'",1)
local month = word("`today'",2)
local year = substr(word("`today'",3),3,2)
if `day' < 10 local `day' = "0`day'"

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
***************************************************/

cd "D:\hm\olim\elior\Kibbutzim"
use data\replication_data, clear

/**************************************************
II. DEFINE `after' AND `before' 
***************************************************/

local act9596_9900Before "1995 1996"
local act9596_9900After "1999 2000"

local Cohs9596 "(year == 1995 | year == 1996)"
local Cohs9900 "(year == 1999 | year == 2000)"

/**************************************************
III. DEFINE SAMPLES 
***************************************************/

// FULL SAMPLE
local allobs "id != ."

// BY GENDER
local boys "boy == 1"
local girls "boy == 0"

/**************************************************
III. GENERATE POST SECONDARY DEPENDENT VARIABLES 
***************************************************/
gen E = (educ > 0 & educ != . )
rename educ_uni uni
gen A = (uni > 0 & uni != .)
rename educ_academiccollege col
gen B = (col > 0 & col != .)
rename educ_teacherscollege teach
gen C = (teach > 0 & teach != .)
rename educ_semiengineer semeng
gen S = (semeng > 0 & semeng != .)

gen ABC = (A == 1 | B == 1 | C == 1)
gen AB = (B == 1 | A == 1)

gen abc = uni + col + teach
gen ab = col + uni 

/**************************************************
IV. RUN BALANCING REGRESSIONS
***************************************************/

local outcomes "E A B C educ uni col teach AB ABC ab abc"

local se "cluster(kibbutz)"

local tgroups "ref9800"

local cgroups "ref0304"

local samples "allobs boys girls"

local cohs "Cohs9596 Cohs9900"

/**************************************************
V. OPEN LOG FILE 
***************************************************/
cap log close
log using "logs\\${name}_`day'`month'`year'.log", replace

postfile values str50 rowKey T1 C1 Dif1 gap T2 C2 Dif2 using "results\automatic\\${name}", replace

foreach sample in `samples' {

	foreach treatment in `tgroups' {

		foreach control in `cgroups' {			
			
			foreach outcome in `outcomes' {
			
				foreach cohort in `cohs' {
		
				cap drop treatment
				cap drop control
				
				gen treatment = `treatment'
				gen control = `control'
				
				// Calculate observations in each group
				di "count if treatment == 1 & ``cohort'' & ``sample'' & `outcome' != . & kibbutz != ."
				count if treatment == 1 & ``cohort'' & ``sample'' & `outcome' != . & kibbutz != .
				local obsT_`outcome'_`cohort'_`sample' = r(N)
				
				di "count if treatment == 0 & ``cohort'' & ``sample'' & `outcome' != . & kibbutz != ."
				count if treatment == 0 & ``cohort'' & ``sample'' & `outcome' != . & kibbutz != .
				local obsC_`outcome'_`cohort'_`sample' = r(N)
				
				// Calculate within-cohort differences
				di ""
				di "********************************************************************"
				di ""
				di "Outcome: `outcome'"
				di ""
				di "Cohort: `cohort'"
				di ""
				di "********************************************************************"
				di ""
				
				di "su `outcome' if treatment == 1 & ``cohort'' & ``sample''"
				su `outcome' if treatment == 1 & ``cohort'' & ``sample''
				
				local meanT_`outcome'_`cohort'_`sample' = r(mean)
				local sdT_`outcome'_`cohort'_`sample' = r(sd)
				local obsT_`outcome'_`cohort'_`sample' = r(N)
				
				di "su `outcome' if control == 1 & ``cohort'' & ``sample''"
				su `outcome' if control == 1 & ``cohort'' & ``sample''
				
				local meanC_`outcome'_`cohort'_`sample' = r(mean)
				local sdC_`outcome'_`cohort'_`sample' = r(sd)
				local obsC_`outcome'_`cohort'_`sample' = r(N)
				
				di "reg `outcome' treatment if ``cohort'' & (treatment | control) & ``sample'', `se'"
				reg `outcome' treatment if ``cohort'' & (treatment | control) & ``sample'', `se'
				
				local difTC_`outcome'_`cohort'_`sample' = _b[treatment]
				local se_difTC_`outcome'_`cohort'_`sample' = _se[treatment] 
				
				}
				
				post values ("M_`outcome' `sample'")	      (`meanT_`outcome'_Cohs9596_`sample'') (`meanC_`outcome'_Cohs9596_`sample'')  (`difTC_`outcome'_Cohs9596_`sample'')     (.) (`meanT_`outcome'_Cohs9900_`sample'')  (`meanC_`outcome'_Cohs9900_`sample'')  (`difTC_`outcome'_Cohs9900_`sample'')  
				post values ("SD/SE_`outcome' `sample'")	  (`sdT_`outcome'_Cohs9596_`sample'')   (`sdC_`outcome'_Cohs9596_`sample'')    (`se_difTC_`outcome'_Cohs9596_`sample'')  (.) (`sdT_`outcome'_Cohs9900_`sample'')    (`sdC_`outcome'_Cohs9900_`sample'')    (`se_difTC_`outcome'_Cohs9900_`sample'')  
				post values ("Gap_`outcome' `sample'")     (.)		                   (.)		                     (.)	                          (.) (.)		                    (.)		                      (.)		  
			}
			
				post values ("Obs `sample'")               (`obsT_E_Cohs9596_`sample'')		   (`obsC_E_Cohs9596_`sample'')	     (.)	                          (.) (`obsT_E_Cohs9900_`sample'')		    (`obsC_E_Cohs9900_`sample'')          (.)	
		}
	}
}

postclose values

/**************************************************
V. REFORMAT DATA TO CSV 
***************************************************/

use "results\automatic\\${name}", clear

outsheet using "results\automatic\\${name}.csv", replace comma

erase "results\automatic\\${name}.dta"

cap log close
