/************************************************

Creator: Elior

Created: Febuary 2014

Description: This file creates Table A22: The Effect
             of the Pay Reform on Post Secondary Schooling
			 (Limited to Age 30)
			 
*************************************************/

clear all
set mem 500m
set matsize 800
set more off
set logtype text

global name Table_A22

local today = "$S_DATE"
local day = word("`today'",1)
local month = word("`today'",2)
local year = substr(word("`today'",3),3,2)
if `day' < 10 local `day' = "0`day'"

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
***************************************************/

cd "D:\hm\olim\elior\Kibbutzim"
use data\replication_data, clear

/**************************************************
II. DEFINE `after' AND `before' 
***************************************************/

local act9596_9900Before "1995 1996"
local act9596_9900After "1999 2000"

/**************************************************
III. DEFINE SAMPLES 
***************************************************/

// FULL SAMPLE
local allobs "id != ."

// LIMIT POST SECONDARY DATA TO PEOPLE WHO HAVE POST SECONDARY EDUCATION BY THE AGE OF 30
foreach var in educ educ_uni educ_academiccollege educ_teacherscollege {
	replace `var' = 0 if limudim30 == 0
}

// BY GENDER
gen girl = (boy == 0)

/**************************************************
III. GENERATE POST SECONDARY DEPENDENT VARIABLES 
***************************************************/
gen E = (educ > 0 & educ != . )
rename educ_uni uni
gen A = (uni > 0 & uni != .)
rename educ_academiccollege col
gen B = (col > 0 & col != .)
rename educ_teacherscollege teach
gen C = (teach > 0 & teach != .)

/**************************************************
IV. RUN DID REGRESSIONS - PART I 
***************************************************/

local depvars "E A B C educ uni col teach"

local controls "boy educ_av educ_em m_ahim eth_*"

local cluster "cluster(kibbutz)"

local tgroups "ref9800"

local cgroups "ref0304"

local samples "allobs"

local sets "act9596_9900"

/**************************************************
V. OPEN LOG FILE 
***************************************************/
cap log close
log using "logs\\${name}_`day'`month'`year'.log", replace

postfile values str50 rowKey E A B C gap educ uni col teach using "results\automatic\\${name}", replace

foreach treatment in `tgroups' {

	foreach control in `cgroups' {
	
		foreach sample in `samples' {
		
			foreach set in `sets' {
			
				// Define after and before periods
				cap drop after
				cap drop before
				cap drop treatment
				cap drop control
				cap drop afterXtreatment
				cap drop yearRelevant
				cap drop _Iyear*
				
				egen after = anymatch(year), values(``set'After')
				egen before = anymatch(year), values (``set'Before')
				
				gen treatment = `treatment'
				gen control = `control' 
				gen afterXtreatment = after * treatment
				
				// Create year dummies
				di ""
				gen yearRelevant = year if (before | after)
				
				di ""
				di "xi i.yearRelevant"
				xi i.yearRelevant
				
					foreach var of varlist `depvars' {
						
						// DID + year dummies + individual controls + kibbutz FE
						di ""
						di "*********************************************************"
						di ""
						di "DID + year dummies + individual controls + kibbutz FE"
						di ""
						di "Outcome: `var'"
						di ""
						di "Cohorts: ``set'After', ``set'Before'
						di ""
						di "Sample: `sample'"
						di ""
						di "*********************************************************"
						di ""
						
						di "areg `var' afterXtreatment _Iyear* `controls' if (before | after) & (treatment | control) & ``sample'', absorb(kibbutz) `cluster'"
						areg `var' afterXtreatment _Iyear* `controls' if (before | after) & (treatment | control) & ``sample'', absorb(kibbutz) `cluster'
						
						loca B1_`var' = _b[afterXtreatment]
						loca SE1_`var' = _se[afterXtreatment]
						
				}
			}
		}
	}
}

post values ("Controlled DID") (`B1_E') (`B1_A') (`B1_B') (`B1_C') (.) (`B1_educ') (`B1_uni') (`B1_col') (`B1_teach')
post values ("Cluster SE") (`SE1_E') (`SE1_A') (`SE1_B') (`SE1_C') (.) (`SE1_educ') (`SE1_uni') (`SE1_col') (`SE1_teach')
post values ("") (.) (.) (.) (.) (.) (.) (.) (.) (.)

/**************************************************
IV. RUN DID REGRESSIONS - PART I 
***************************************************/
local depvars "E A B C educ uni col teach"

local controls "boy educ_av educ_em m_ahim eth_*"

local cluster "cluster(kibbutz)"

local tgroups "ref9800"

local cgroups "ref0304"

local samples "girl"

local sets "act9596_9900"

foreach treatment in `tgroups' {

	foreach control in `cgroups' {
		
			foreach set in `sets' {
			
				// Define after and before periods
				cap drop after
				cap drop before
				cap drop treatment
				cap drop control
				cap drop afterXtreatment
				cap drop yearRelevant
				cap drop _Yyear*
				
				egen after = anymatch(year), values(``set'After')
				egen before = anymatch(year), values (``set'Before')
				
				gen treatment = `treatment'
				gen control = `control' 
				gen afterXtreatment = after * treatment
				
				// Create year dummies
				di ""
				gen yearRelevant = year if (before | after)
				
				di ""
				di "xi i.yearRelevant"
				xi i.yearRelevant, prefix(_Y)
				
				// CREATE KIBBUTZ DUMMIES
				cap drop Rel 
				gen Rel = kibbutz if (before | after) & (treatment | control)
				xi i.Rel, prefix(_Kib)
				
					foreach sample in `samples' {
					
						gen afterXtreatmentX`sample' = (`sample' == 1 & afterXtreatment == 1)
						
							foreach x in boy educ_av educ_em m_ahim eth_aa eth_ea eth_imm eth_fsu eth_eth {
							
								gen `x'X`sample' = `x' * `sample' 
							}
						
						local controlsX`sample' "boyX`sample' educ_avX`sample' educ_emX`sample' m_ahimX`sample' eth_aaX`sample' eth_eaX`sample' eth_immX`sample' eth_fsuX`sample' eth_ethX`sample'"
				
						foreach year in _YyearRelev_1996 _YyearRelev_1999 _YyearRelev_2000 {
							
							gen `year'X`sample' = `year' * `sample' 
						}

						foreach var of varlist `depvars' {
							
							// DID + year dummies + individual controls + kibbutz FE
							di ""
							di "*********************************************************"
							di ""
							di "DID + year dummies + individual controls + kibbutz FE"
							di ""
							di "Outcome: `var'"
							di ""
							di "Cohorts: ``set'After', ``set'Before'"
							di ""
							di "Sample: `sample' == 1 OR 0"
							di ""
							di "*********************************************************"
							di ""
							
							di "xi: reg `var' afterXtreatment afterXtreatmentX`sample' `sample' `controls' `controlsX`sample'' _Yyear* i.Rel*I.`sample' if (before | after) & (treatment | control),  `cluster'"
							xi: reg `var' afterXtreatment afterXtreatmentX`sample' `sample' `controls' `controlsX`sample'' _Yyear* i.Rel*I.`sample' if (before | after) & (treatment | control),  `cluster'
							
							local B3_`var' = _b[afterXtreatment]
							local SE3_`var' = _se[afterXtreatment]
							
							local B4_`var' = _b[afterXtreatment] + _b[afterXtreatmentX`sample']
							
							matrix V = e(V)
							
							local SE4_`var' = sqrt(V[1,1] + V[2,2] + 2 * V[2,1])
						
					}
				}	
			}
		}
	}

post values ("Controlled DID `sample' 1") (`B3_E') (`B3_A') (`B3_B') (`B3_C') (.) (`B3_educ') (`B3_uni') (`B3_col') (`B3_teach')
post values ("Cluster SE") (`SE3_E') (`SE3_A') (`SE3_B') (`SE3_C') (.) (`SE3_educ') (`SE3_uni') (`SE3_col') (`SE3_teach')
post values ("") (.) (.) (.) (.) (.) (.) (.) (.) (.)

post values ("Controlled DID `sample' 0") (`B4_E') (`B4_A') (`B4_B') (`B4_C') (.) (`B4_educ') (`B4_uni') (`B4_col') (`B4_teach')
post values ("Cluster SE") (`SE4_E') (`SE4_A') (`SE4_B') (`SE4_C') (.) (`SE4_educ') (`SE4_uni') (`SE4_col') (`SE4_teach')
post values ("") (.) (.) (.) (.) (.) (.) (.) (.) (.)

postclose values

/**************************************************
V. REFORMAT DATA TO CSV 
***************************************************/

use "results\automatic\\${name}", clear

outsheet using "results\automatic\\${name}.csv", replace comma

erase "results\automatic\\${name}.dta"

cap log close
