/***************************************************

Creator:	Elior

Date:		February 2014

Description: This file creates TABLE A3 in the online appendix:
			 Distribution of Kibbutzim, Schools and
			 Students by Year of Reform and by 10th Grade Cohorts

*****************************************************/

clear all
set mem 200m
set matsize 800
set more off
set logtype text

global name Table_A3

local today="$S_DATE"
local day=word("`today'",1)
local month=word("`today'",2)
local year=substr(word("`today'",3),3,2)
if `day'<10 local day="0`day'" 

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
**************************************************/
cd "C:\Users\msvictor3\Dropbox\Work\Kibbutzim\Kibbutzim_ECMA"

use data\kibbutzim, clear

/*******************************************
II. Define samples
*******************************************/
local allobs "id !=."


/*******************************************
II. Define "before" and "after"
*******************************************/

local Cohs9596 "(year==1995| year==1996)"
local Cohs9900 "(year==1999| year==2000)"

// DEFINE PARTIAL TREATMENT REFORM INDICATOR 
gen ref0102 = (year_of_reform == 2001 | year_of_reform == 2002) 

/*******************************************
III. Compute Sample Sizes
*******************************************/
local tgroups "ref9800"

local cgroups "ref0102 ref0304"

local samples "allobs"

local cohs "Cohs9596 Cohs9900"

postfile values str50 rowKey N1 N2 N3 using "results\automatic\\${name}", replace

*******Open log******* 
cap log close
log using "logs\\${name}_`day'`month'`year'.log", replace

foreach sample in `samples' {

	foreach treatment in `tgroups'  {

		foreach control in `cgroups' {

				foreach cohort in `cohs'  {

					cap drop treatment
					cap drop control

					di "gen treatment=`treatment'"
					gen treatment=`treatment'
					di ""

					di "gen control=`control'"
					gen control=`control'
					di ""

					//Calculate observations in each group
					*Treatment
					di "count if treatment==1 & ``cohort'' & ``sample'' & kibbutz !=."
					count if treatment==1 & ``cohort'' & ``sample'' & kibbutz !=.
					di ""
					local obsT_`cohort'=r(N)

					*Control
					di "count if control==1 & ``cohort'' & ``sample''  & kibbutz !=."
					count if control==1 & ``cohort'' & ``sample'' & kibbutz !=.
					di ""
					local obsC_`cohort'_`control'=r(N)

					di "unique kibbutz if `treatment' == 1 & ``cohort'' & ``sample''"
					unique kibbutz if `treatment' == 1 & ``cohort'' & ``sample''
					local locs_`cohort'_`treatment' = r(sum)
				
					di "unique kibbutz if `control' == 1 & ``cohort'' & ``sample''"
					unique kibbutz if `control' == 1 & ``cohort'' & ``sample''
					local locs_`cohort'_`control' = r(sum)
			}

			cap log close
		}
	}
}

post values ("kibbutzim_coh9596") (`locs_Cohs9596_ref9800')  (`locs_Cohs9596_ref0102') (`locs_Cohs9596_ref0304')     
post values ("Obs")               (`obsT_Cohs9596')	         (`obsC_Cohs9596_ref0102') (`obsC_Cohs9596_ref0304')	     
post values ("Gap")               (.)		                 (.)		               (.)	                        

post values ("kibbutzim_coh9900") (`locs_Cohs9900_ref9800')  (`locs_Cohs9900_ref0102') (`locs_Cohs9900_ref0304') 	
post values ("Obs")               (`obsT_Cohs9900')	         (`obsC_Cohs9900_ref0102') (`obsC_Cohs9900_ref0304')	 
post values ("Gap")               (.)		                 (.)		               (.)	                        


postclose values

/*************************************************************
IV. Reformat from dta to csv
**************************************************************/

use "results\automatic\\${name}", clear

outsheet using "results\automatic\\${name}_`day'`month'`year'.csv", replace comma

erase "results\automatic\\${name}.dta"

cap log close
