/***************************************************

Creator:	Elior

Date:		February 2014

Description: This file creates TABLE A6 in the online appendix:
			 Balancing Test of Students' Characteristics in Treatment and Control Kibbutzim
             Treatment Kibbutzim : Reformed fully in 1998-2000; Control Kibbutzim : Reformed 2003-04
             Controlling for all background characteristics in one regression                       

*****************************************************/

clear all
set mem 200m
set matsize 800
set more off
set logtype text

global name Table_A6

local today="$S_DATE"
local day=word("`today'",1)
local month=word("`today'",2)
local year=substr(word("`today'",3),3,2)
if `day'<10 local day="0`day'" 

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
**************************************************/
cd "C:\Users\msvictor3\Dropbox\Work\Kibbutzim\Kibbutzim_ECMA"

use data\kibbutzim, clear

/*******************************************
II. Define samples
*******************************************/
local allobs "id !=."

/*******************************************
III. Define "before" and "after"
*******************************************/

local Cohs9596 "(year==1995| year==1996)"
local Cohs9900 "(year==1999| year==2000)"
local pooled "(year==1995| year==1996|year==1999| year==2000)"

// DEFINE FULL REFORM INDICATOR
gen ref9800_reshet =(ref9800==1 & reshet==1)

/*******************************************
IV. Run balancing regressions
*******************************************/
local backgrounds "boy educ_av educ_em m_ahim eth_aa eth_ea eth_imm eth_fsu"

local se "cluster(kibbutz)"

local tgroups "ref9800_reshet"

local cgroups "ref0304"

local samples "allobs"

local cohs "Cohs9596 Cohs9900 pooled"

*******Open log******* 
cap log close
log using "logs\\${name}_`day'`month'`year'.log", replace

postfile values str50 rowKey T1 T2 T3 using "results\automatic\\${name}", replace

xi I.year, prefix(_I)
	
foreach sample in `samples' {

	foreach treatment in `tgroups'  {

		foreach control in `cgroups' {

					cap drop treatment
					cap drop control

					di "gen treatment=`treatment'"
					gen treatment=`treatment'
					di ""

					di "gen control=`control'"
					gen control=`control'
					di ""
					
			foreach cohort in `cohs'  {
			
				//Calculate observations in each group
				*Treatment
				di "count if treatment==1 & ``cohort'' & ``sample'' & kibbutz !=."
				count if treatment==1 & ``cohort'' & ``sample'' & kibbutz !=.
				di ""
				scalar obsT_`cohort'=r(N)

				*Control
				di "count if control==1 & ``cohort'' & ``sample'' & kibbutz !=."
				count if control==1 & ``cohort'' & ``sample'' & kibbutz !=.
				di ""
				scalar obsC_`cohort'=r(N)
				
				local obs_`cohort' = obsT_`cohort' + obsC_`cohort'

				
				di "reg treatment `backgrounds' _I* if ``cohort'' & (treatment==1| control==1) & ``sample'', `se'"
				reg treatment `backgrounds' _I* if ``cohort'' & (treatment==1| control==1) & ``sample'', `se'
				di ""
				
					foreach bground in `backgrounds' {
					
						local B_`bground'_`cohort'     = _b[`bground']
						local se_`bground'_`cohort'  = _se[`bground']
					}
				
				test `backgrounds' 
				local F_`cohort' = r(F)
				local P_`cohort' = r(p)
				
			}
			
			foreach bground in `backgrounds' {
					
					post values ("B_`bground'")	      (`B_`bground'_Cohs9596')     (`B_`bground'_Cohs9900')		(`B_`bground'_pooled') 
					post values ("SD/SE_`bground'")	  (`se_`bground'_Cohs9596')    (`se_`bground'_Cohs9900')    (`se_`bground'_pooled')   
					post values ("Gap_`bground'")     (.)	                       (.)		                    (.)                      		  
				}
			
			post values ("F-STATISTIC")		    (`F_Cohs9596')		(`F_Cohs9900')		(`F_pooled')
			post values ("Gap")     			(.)	                (.)		            (.)     
			post values ("P-VALUE")				(`P_Cohs9596')		(`P_Cohs9900')		(`P_pooled')
			post values ("Gap")     			(.)	                (.)		            (.)     
			post values ("Obs")					(`obs_Cohs9596')	(`obs_Cohs9900')	(`obs_pooled')
				
			
			

			cap log close
		}
	}
}

postclose values
/*************************************************************
III. Reformat from dta to csv
**************************************************************/

use "results\automatic\\${name}", clear

outsheet using "results\automatic\\${name}_`day'`month'`year'.csv", replace comma

erase "results\automatic\\${name}.dta"

