/***************************************************

Creator:	Elior

Date:		February 2014

Description: This file creates TABLE A9 in the paper:
			 Balancing Tests of Students' Characteristics and Outcomes
			 in Treatment and Control Kibbutzim Treatment Kibbutzim : 
			 Reformed fully in 1998-2000; Control Kibbutzim : Reformed partially in 1998-2000

*****************************************************/

clear all
set mem 200m
set matsize 800
set more off
set logtype text

global name Table_A9

local today="$S_DATE"
local day=word("`today'",1)
local month=word("`today'",2)
local year=substr(word("`today'",3),3,2)
if `day'<10 local day="0`day'" 

/**************************************************
I. ENTER THE PATH NAME WHERE THE DATA FILE IS FOUND
**************************************************/
cd "C:\Users\msvictor3\Dropbox\Work\Kibbutzim\Kibbutzim_ECMA"

use data\kibbutzim, clear

/*******************************************
II. Define samples
*******************************************/
local allobs "id !=."

/*******************************************
III. Define "before" and "after"
*******************************************/

local Cohs9596 "(year==1995| year==1996)"
local Cohs9900 "(year==1999| year==2000)"

// DEFINE PARTIAL REFORM INDICATOR
gen ref9800_meshulav =(ref9800==1 & meshulav==1)

// DEFINE FULL REFORM INDICATOR
gen ref9800_reshet =(ref9800==1 & reshet==1)

/*******************************************
IV. Run balancing regressions
*******************************************/
local backgrounds "boy educ_av educ_em m_ahim eth_aa eth_ea eth_imm eth_fsu"

local outcomes "graduate wmean zakai_bagrut university"

local se "cluster(kibbutz)"

local tgroups "ref9800_reshet"

local cgroups "ref9800_meshulav"

local samples "allobs"

local cohs "Cohs9596 Cohs9900"

*******Open log******* 
cap log close
log using "logs\\${name}_`day'`month'`year'.log", replace

postfile values str50 rowKey T1 C1 Dif1 gap T2 C2 Dif2 using "results\automatic\\${name}", replace

foreach sample in `samples' {

	foreach treatment in `tgroups'  {

		foreach control in `cgroups' {

			foreach bground of varlist `backgrounds' {

				foreach cohort in `cohs'  {

					cap drop treatment
					cap drop control

					di "gen treatment=`treatment'"
					gen treatment=`treatment'
					di ""

					di "gen control=`control'"
					gen control=`control'
					di ""

					//Calculate observations in each group
					*Treatment
					di "count if treatment==1 & ``cohort'' & ``sample'' & `bground' !=. & kibbutz !=."
					count if treatment==1 & ``cohort'' & ``sample'' & `bground' !=. & kibbutz !=.
					di ""
					local obsT_`bground'_`cohort'=r(N)

					*Control
					di "count if control==1 & ``cohort'' & ``sample'' & `bground' !=. & kibbutz !=."
					count if control==1 & ``cohort'' & ``sample'' & `bground' !=. & kibbutz !=.
					di ""
					local obsC_`bground'_`cohort'=r(N)

					//Calculate within-cohort differences
					di ""
					di "**********************************************************************************"
					di ""
					di "Background: `bground'"
					di ""
					di "Cohort: `cohort'"
					di ""
					di "**********************************************************************************"
					di ""

					di "su `bground'  if treatment==1 & ``cohort'' & ``sample''"
					su `bground'  if treatment==1 & ``cohort'' & ``sample''
					di ""
					local meanT_`bground'_`cohort'=r(mean)
					local sdT_`bground'_`cohort'=r(sd)
					local obsT_`bground'_`cohort'=r(N)

					di "su `bground'  if control==1 & ``cohort'' & ``sample''"
					su `bground'  if control==1 & ``cohort'' & ``sample''
					di ""
					local meanC_`bground'_`cohort'=r(mean)
					local sdC_`bground'_`cohort'=r(sd)
					local obsC_`bground'_`cohort'=r(N)

					di "reg `bground' treatment if ``cohort'' & (treatment==1| control==1) & ``sample'', `se'"
					reg `bground' treatment if ``cohort'' & (treatment==1| control==1) & ``sample'', `se'
					di ""
					local difTC_`bground'_`cohort'     = _b[treatment]
					local se_difTC_`bground'_`cohort'  = _se[treatment]
					
				}


				post values ("M_`bground'")	      (`meanT_`bground'_Cohs9596') (`meanC_`bground'_Cohs9596')  (`difTC_`bground'_Cohs9596')     (.) (`meanT_`bground'_Cohs9900')  (`meanC_`bground'_Cohs9900')  (`difTC_`bground'_Cohs9900')  
				post values ("SD/SE_`bground'")	  (`sdT_`bground'_Cohs9596')   (`sdC_`bground'_Cohs9596')    (`se_difTC_`bground'_Cohs9596')  (.) (`sdT_`bground'_Cohs9900')    (`sdC_`bground'_Cohs9900')    (`se_difTC_`bground'_Cohs9900')  
				post values ("Gap_`bground'")     (.)		                   (.)		                     (.)	                          (.) (.)		                    (.)		                      (.)		  
			}
			
			foreach cohort in `cohs'  {
			
				xi I.year, prefix(_I)	
				di "reg treatment `backgrounds' _I* if ``cohort'' & (treatment==1| control==1) & ``sample'', `se'"
				reg treatment `backgrounds' _I* if ``cohort'' & (treatment==1| control==1) & ``sample'', `se'
				di ""
				
				test `backgrounds' 
				local F_`cohort' = r(F)
				local P_`cohort' = r(p)
				
				drop _I*
				
			}
			
		
			foreach outcome of varlist `outcomes' {

				foreach cohort in `cohs'  {

					cap drop treatment
					cap drop control

					di "gen treatment=`treatment'"
					gen treatment=`treatment'
					di ""

					di "gen control=`control'"
					gen control=`control'
					di ""

					//Calculate observations in each group
					*Treatment
					di "count if treatment==1 & ``cohort'' & ``sample'' & `outcome' !=. & kibbutz !=."
					count if treatment==1 & ``cohort'' & ``sample'' & `outcome' !=. & kibbutz !=.
					di ""
					local obsT_`outcome'_`cohort'=r(N)

					*Control
					di "count if control==1 & ``cohort'' & ``sample'' & `outcome' !=. & kibbutz !=."
					count if control==1 & ``cohort'' & ``sample'' & `outcome' !=. & kibbutz !=.
					di ""
					local obsC_`outcome'_`cohort'=r(N)

					//Calculate within-cohort differences
					di ""
					di "**********************************************************************************"
					di ""
					di "Outcome: `outcome'"
					di ""
					di "Cohort: `cohort'"
					di ""
					di "**********************************************************************************"
					di ""

					di "su `outcome'  if treatment==1 & ``cohort'' & ``sample''"
					su `outcome'  if treatment==1 & ``cohort'' & ``sample''
					di ""
					local meanT_`outcome'_`cohort'=r(mean)
					local sdT_`outcome'_`cohort'=r(sd)
					local obsT_`outcome'_`cohort'=r(N)

					di "su `outcome'  if control==1 & ``cohort'' & ``sample''"
					su `outcome'  if control==1 & ``cohort'' & ``sample''
					di ""
					local meanC_`outcome'_`cohort'=r(mean)
					local sdC_`outcome'_`cohort'=r(sd)
					local obsC_`outcome'_`cohort'=r(N)

					di "reg `outcome' treatment if ``cohort'' & (treatment==1| control==1) & ``sample'', `se'"
					reg `outcome' treatment if ``cohort'' & (treatment==1| control==1) & ``sample'', `se'
					di ""
					local difTC_`outcome'_`cohort'     = _b[treatment]
					local se_difTC_`outcome'_`cohort'  = _se[treatment]
					
				}


				post values ("M_`outcome'")	      (`meanT_`outcome'_Cohs9596') (`meanC_`outcome'_Cohs9596')  (`difTC_`outcome'_Cohs9596')     (.) (`meanT_`outcome'_Cohs9900')  (`meanC_`outcome'_Cohs9900')  (`difTC_`outcome'_Cohs9900')  
				post values ("SD/SE_`outcome'")	  (`sdT_`outcome'_Cohs9596')   (`sdC_`outcome'_Cohs9596')    (`se_difTC_`outcome'_Cohs9596')  (.) (`sdT_`outcome'_Cohs9900')    (`sdC_`outcome'_Cohs9900')    (`se_difTC_`outcome'_Cohs9900')  
				post values ("Gap_`outcome'")     (.)		                   (.)		                     (.)	                          (.) (.)		                    (.)		                      (.)		  
			}
				post values ("gap")               (.)                          (.)					         (.)                              (.)  (.)                         (.)                            (.)
				post values ("Obs")               (`obsT_boy_Cohs9596')	       (`obsC_boy_Cohs9596')	     (.)	                          (.)  (`obsT_boy_Cohs9900')       (`obsC_boy_Cohs9900')          (.)
				post values ("Gap")               (.)		                   (.)		                     (.)	                          (.)  (.)		                   (.)		                      (.)
	
		}
	}
}

postclose values

cap log close

/*************************************************************
III. Reformat from dta to csv
**************************************************************/

use "results\automatic\\${name}", clear

outsheet using "results\automatic\\${name}.csv", replace comma

erase "results\automatic\\${name}.dta"



